@@ -7,7 +7,6 @@ import org.slf4j.LoggerFactory;
 import com.openexchange.antiabuse.AllowParameters;
 import com.openexchange.antiabuse.AntiAbuseService;
 import com.openexchange.antiabuse.ReportParameters;
-import com.openexchange.antiabuse.ReportValue;
 import com.openexchange.antiabuse.Status;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.antiabuse.osgi.Services;
@@ -23,11 +22,8 @@ public class WeakforcedImpl {
         AntiAbuseService wf;
         properties = new HashMap<String, String> ();
         properties.put("app", "oxguard");
-        try {
-            wf = Services.getService(AntiAbuseService.class);
-        } catch (OXException e) {
-            return null;
-        }
+        wf = Services.getServiceLookup().getOptionalService(AntiAbuseService.class);
+
         return (wf);
     }
 
