@@ -38,6 +38,7 @@ import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.guard.translation.GuardTranslationService;
+import com.openexchange.jslob.JSlobService;
 import com.openexchange.osgi.HousekeepingActivator;
 
 public class Activator extends HousekeepingActivator {
@@ -65,18 +66,13 @@ public class Activator extends HousekeepingActivator {
 
         registerService(AutoCryptStorageService.class, storageService);
 
-        registerService (AutoCryptService.class, new AutoCryptServiceImpl(
-            this.getService(GuardKeyService.class),
-            this.getService(GuardConfigurationService.class),
-            storageService,
-            this.getService(MailCreatorService.class),
-            this.getService(GuardTranslationService.class),
-            this.getService(GuardNotificationService.class),
-            this.getService(GuardRatifierService.class)));
+        registerService(AutoCryptService.class, new AutoCryptServiceImpl(this));
 
         // Register service to create autoCrypt table
         registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new CreateAutoCryptTableTask(databaseService)));
         registerService(CreateTableService.class, new CreateAutoCryptTable());
+        trackService(JSlobService.class);
+        openTrackers();
 
     }
 
