@@ -32,22 +32,12 @@ import java.io.OutputStreamWriter;
 import java.io.Writer;
 import java.nio.charset.StandardCharsets;
 import java.rmi.RemoteException;
-import java.util.HashMap;
-import java.util.Map;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.BlockingQueue;
 import javax.management.MBeanException;
-import javax.management.MBeanServerConnection;
-import javax.management.MBeanServerInvocationHandler;
-import javax.management.MalformedObjectNameException;
-import javax.management.ObjectName;
-import javax.management.remote.JMXConnector;
-import javax.management.remote.JMXConnectorFactory;
-import javax.management.remote.JMXServiceURL;
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Options;
 import com.openexchange.auth.rmi.RemoteAuthenticator;
-import com.openexchange.cli.AbstractRmiCLI;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.common.util.CipherUtil;
@@ -60,13 +50,9 @@ import com.openexchange.guard.management.maintenance.internal.TestUserResult;
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  */
-public class Guard extends AbstractRmiCLI<Void> {
+public class Guard extends AbstractGuardCLT {
 
-    private final char[] optionsWithArgs = { 't', 'e', 'n', 'u', 'j', 'w', 'o', 'x', 'g', 'm', 'r', 'c' };
-
-    private static final String serviceURL = "service:jmx:rmi:///jndi/rmi://";
-
-    private static final String DEFAULT_CONF_FOLDER = "/opt/open-xchange/etc";
+    private final char[] optionsWithArgs = { 't', 'e', 'n', 'u', 'j', 'w', 'o', 'x', 'g', 'm', 'r', 'c', 'a' };
 
     private final Boolean requiresAuth;
 
@@ -242,14 +228,8 @@ public class Guard extends AbstractRmiCLI<Void> {
         return null;
     }
 
-    private GuardMaintenanceMBean createProxy(String jmxHost, String jmxPort, String jmxUser, String jmxPassword) throws MalformedObjectNameException, IOException {
-        ObjectName objectName = getObjectName();
-        MBeanServerConnection mbeanServerConnection = connect(jmxHost, jmxPort, jmxUser, jmxPassword);
-        return MBeanServerInvocationHandler.newProxyInstance(mbeanServerConnection, objectName, GuardMaintenanceMBean.class, false);
-    }
-
     private void reset(GuardMaintenanceMBean proxy, String email) throws MBeanException {
-        proxy.reset(email);
+        proxy.reset(email, "pgp");
         System.out.println("Email with a new password has been sent.");
     }
 
@@ -362,12 +342,6 @@ public class Guard extends AbstractRmiCLI<Void> {
         return "guard [-i [-d /custom/path]] [-t john.doe@example.com] [-u joan.doe@ox.io] [-e john.doe@example.com] [-n joan.doe@example.com] [-j jmxUser] " + "[-w jmxPassword] [-x jmx.host] [-o <JMX_PORT>] [-p <RMI_PORT>] [--responsetimeout <TIMEOUT>]";
     }
 
-    private MBeanServerConnection connect(String jmxHost, String jmxPort, String jmxUser, String jmxPassword) throws IOException {
-        JMXServiceURL jmxServiceURL = new JMXServiceURL(serviceURL + jmxHost + ":" + jmxPort + "/server");
-        JMXConnector jmxConnector = JMXConnectorFactory.connect(jmxServiceURL, createEnvironment(jmxUser, jmxPassword));
-        return jmxConnector.getMBeanServerConnection();
-    }
-
     private void initialise(String directory) throws IOException {
         // Verify that the specified path is a directory
         File f = new File(directory);
@@ -474,28 +448,7 @@ public class Guard extends AbstractRmiCLI<Void> {
         System.out.println("done.");
     }
 
-    /**
-     * Create JMX Environment
-     *
-     * @return
-     */
-    private static Map<String, Object> createEnvironment(String jmxUser, String jmxPassword) {
-        Map<String, Object> environment = new HashMap<String, Object>();
-        if (jmxUser != null && jmxPassword != null) {
-            environment.put(JMXConnector.CREDENTIALS, new String[] { jmxUser, jmxPassword });
-        }
-        return environment;
-    }
 
-    /**
-     * Returns the {@link ObjectName}
-     *
-     * @return the {@link ObjectName}
-     * @throws MalformedObjectNameException
-     */
-    private ObjectName getObjectName() throws MalformedObjectNameException {
-        return new ObjectName(GuardMaintenanceMBean.DOMAIN, GuardMaintenanceMBean.KEY, GuardMaintenanceMBean.VALUE);
-    }
 
     /**
      * A simple {@link InputStream} processor
