@@ -64,6 +64,20 @@ public class AntiAbuseUtils {
             );
     }
 
+    public static AllowParameters getAllowParameters(String clientIp, String userAgent, String scheme, int userid, int cid, String password) {
+        return getAllowParameters(clientIp, userAgent, scheme, userid + "-" + cid, password);
+    }
+
+    public static AllowParameters getAllowParameters (String clientIp, String userAgent, String scheme, String login, String password) {
+        return getAllowParameter (
+            login,
+            password,
+            clientIp,
+            userAgent,
+            scheme.toLowerCase().contains("https") ? Protocol.HTTPS : Protocol.HTTP
+            );
+    }
+
     /**
      * Create antiabuse AllowParameter from elements
      * @param login
@@ -96,6 +110,10 @@ public class AntiAbuseUtils {
         return getReportParameter (success, request, userId + "-" + cid, password);
     }
 
+    public static ReportParameters getReportParameter(boolean success, String ip, String userAgent, String scheme, int userId, int cid, String password) {
+        return getReportParameter(success, ip, userAgent, scheme, userId + "-" + cid, password);
+    }
+
     /**
      * Overload method to create report Parameter from Http Request object
      * @param success
@@ -114,6 +132,16 @@ public class AntiAbuseUtils {
                 request.getScheme().toLowerCase().contains("https") ? Protocol.HTTPS : Protocol.HTTP);
     }
 
+    public static ReportParameters getReportParameter (boolean success,  String ip, String userAgent, String scheme, String login, String password) {
+        return getReportParameter (
+            success ? ReportValue.SUCCESS : ReportValue.FAILURE,
+            login,
+            password,
+            ip,
+            userAgent,
+            scheme.toLowerCase().contains("https") ? Protocol.HTTPS : Protocol.HTTP);
+    }
+
     /**
      * Overload method to create report from AllowParameter
      * @param reportValue
