@@ -21,12 +21,17 @@
 
 package com.openexchange.guard.common.servlets.utils;
 
+import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.L;
 import java.io.ByteArrayInputStream;
 import java.io.Closeable;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.charset.Charset;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.Map.Entry;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.io.IOUtils;
@@ -34,8 +39,10 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.gson.JsonElement;
+import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.responses.CommonResponse;
+import com.openexchange.guard.common.util.IDNUtil;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 
 /**
@@ -54,7 +61,6 @@ public class ServletUtils {
      * @return the requesting client's remote address
      */
     public static String getClientIP(HttpServletRequest request) {
-
         if (request.getHeader("X-Forwarded-For") != null) {
             return (request.getHeader("X-Forwarded-For"));
         }
@@ -67,7 +73,7 @@ public class ServletUtils {
      * @param response the response object
      * @param returnCode the return code to send
      * @param answer the answer to send
-     * @throws IOException
+     * @throws IOException In case response can't be sent
      */
     public static void sendResponse(HttpServletResponse response, int returnCode, String answer) throws IOException {
         response.setContentType("text/html; charset=UTF-8");
@@ -100,6 +106,7 @@ public class ServletUtils {
 
     /**
      * Sends 200 - OK
+     *
      * @param response The reponse to send the 200 code to
      * @param type The content type to use
      * @param answer the answer to send
@@ -139,6 +146,14 @@ public class ServletUtils {
             LOG.error("Error sending OK message", e);
         }
     }
+    /**
+     * Send JSON response
+     *
+     * @param response the response to send the 200 code to
+     */
+    public static void sendJsonOK(HttpServletResponse response) {
+        sendJsonOK(response, new JsonObject());
+    }
 
     /**
      * Send JSON response
@@ -151,6 +166,19 @@ public class ServletUtils {
         sendJson(response, json);
     }
 
+    /**
+     * Send JSON response
+     *
+     * @param response the response to send the 200 code to
+     * @param error The error object to put into the body with content type application/json
+     */
+    public static void sendJsonError(HttpServletResponse response, String error) {
+        JsonObject el = new JsonObject();
+        el.addProperty("error", error);
+        sendJson(response, el);
+
+    }
+
     /**
      * Send JSON response
      *
@@ -176,18 +204,15 @@ public class ServletUtils {
      *
      * @param response The response to use
      * @param responseObject The {@link Closeable} to send and close
-     * @throws OXException
      */
-    public static void sendObject(HttpServletResponse response, Closeable responseObject) throws OXException {
+    public static void sendObject(HttpServletResponse response, Closeable responseObject) {
         try {
-            sendObject(response, (Object)responseObject);
-        }
-        finally {
+            sendObject(response, (Object) responseObject);
+        } finally {
             try {
                 responseObject.close();
             } catch (IOException e) {
                 LOG.error("IO Error", e);
-                e.printStackTrace();
             }
         }
     }
@@ -238,7 +263,7 @@ public class ServletUtils {
      * Sends 405 - Internal server error
      *
      * @param response the response to send the 405 code to
-     * @param answer body text
+     * @param e body text
      */
     public static void sendError(HttpServletResponse response, Throwable e) {
         String answer = (e.getMessage() == null ? "" : e.getMessage());
@@ -303,10 +328,26 @@ public class ServletUtils {
         try {
             return (ServletUtils.getStringParameter(request, name, false));
         } catch (OXException e) {
+            LOG.debug("Unable to parse", e);
             return null;
         }
     }
 
+    /**
+     * Returns IDN ACE'd email from parameter
+     *
+     * @param request Http servlet request
+     * @param name Parameter name
+     * @return Ace encoded email address
+     */
+    public static String getEmailParameter(HttpServletRequest request, String name) {
+        final String email = getStringParameter(request, name);
+        if (email != null) {
+            return IDNUtil.aceEmail(email);
+        }
+        return email;
+    }
+
     /**
      * Get integer from HttpServletRequest
      *
@@ -321,13 +362,12 @@ public class ServletUtils {
         if (item == null || item.equals("null")) {
             if (mandatory) {
                 throw GuardCoreExceptionCodes.PARAMETER_MISSING.create(name);
-            } else {
-                return null;
             }
+            return null;
         }
         try {
             int val = Integer.parseInt(item);
-            return (val);
+            return I(val);
         } catch (Exception e) {
             LOG.error("Problem getting integer from parameter", e);
             throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
@@ -343,8 +383,9 @@ public class ServletUtils {
      */
     public static Integer getIntParameter(HttpServletRequest request, String name) {
         try {
-            return (getIntParameter(request, name, false));
+            return getIntParameter(request, name, false);
         } catch (OXException e) {
+            LOG.debug("Unable to parser parameter", e);
             return null;
         }
     }
@@ -363,12 +404,11 @@ public class ServletUtils {
         if (item == null || item.equals("null")) {
             if (mandatory) {
                 throw GuardCoreExceptionCodes.PARAMETER_MISSING.create(name);
-            } else {
-                return null;
             }
+            return null;
         }
         try {
-            return Long.parseLong(item.trim());
+            return L(Long.parseLong(item.trim()));
         } catch (Exception e) {
             LOG.error("Problem getting long from parameter", e);
             throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
@@ -396,7 +436,6 @@ public class ServletUtils {
      * @param request the request to get the boolean value from
      * @param name the name of the parameter to get as boolean
      * @return The value of the requested parameter as boolean
-     * @throws OXException If the requested parameter was not found
      */
     public static boolean getBooleanParameter(HttpServletRequest request, String name) {
         try {
@@ -425,7 +464,118 @@ public class ServletUtils {
         return false;
     }
 
+    /**
+     * Gets a value indicating whether the given parameter is contained in the request or not
+     *
+     * @param request The request
+     * @param name The parameter name
+     * @return <code>true</code> if the parameter is in the request, <code>false</code> otherwise
+     */
     public static boolean hasParameter(HttpServletRequest request, String name) {
         return request.getParameterMap().containsKey(name);
     }
+
+    /**
+     * Gets String from parameter map with specified key
+     *
+     * @param map Parameter map to search
+     * @param name Key to look up
+     * @param mandatory Throw missing expection if missing and mandatory
+     * @return String value, null if missing, throws Error if missing and mandatory
+     * @throws OXException
+     */
+    public static String getStringParameter(Map<String, String[]> map, String name, boolean mandatory) throws OXException {
+        String[] items = map.get(name);
+        if (items == null && mandatory) {
+            throw GuardCoreExceptionCodes.PARAMETER_MISSING.create(name);
+        }
+        if (items == null) {
+            return null;
+        }
+        String item = items[0];
+        if (item.isEmpty() && mandatory) {
+            throw GuardCoreExceptionCodes.PARAMETER_MISSING.create(name);
+        }
+        return item;
+    }
+
+    /**
+     * Parse a long value from parameter map
+     *
+     * @param map Map to use
+     * @param name Key value for lookup
+     * @param mandatory Throw error if missing
+     * @return Long value, null if missing, or error if mandatory and missing
+     * @throws OXException
+     */
+    public static Long getLongParameter(Map<String, String[]> map, String name, boolean mandatory) throws OXException {
+        String item = getStringParameter(map, name, mandatory);
+        if (item == null || item.isEmpty()) {
+            return null;
+        }
+        try {
+            return L(Long.parseLong(item.trim()));
+        } catch (Exception e) {
+            LOG.error("Problem getting long from parameter", e);
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
+        }
+    }
+
+    /**
+     * Parse a boolean value from parameter map
+     *
+     * @param map Map to use
+     * @param name Key value for lookup
+     * @param mandatory Throw error if missing
+     * @return boolean value, false if missing, or error if mandatory and missing
+     * @throws OXException
+     */
+    public static boolean getBooleanParameter(Map<String, String[]> map, String name, boolean mandatory) throws OXException {
+        String item = getStringParameter(map, name, mandatory);
+        if (item == null) {
+            return false;
+        }
+        return item.equalsIgnoreCase("true");
+    }
+
+    /**
+     * Parses the parameter map from the given request
+     *
+     * @param map The request to parse the parameters from
+     * @return The flat map including all the parameters parsed from the request
+     */
+    public static Map<String, Object> getMapParameters(HttpServletRequest request) {
+        return getMapParameters(request.getParameterMap());
+    }
+
+    /**
+     * Parses the given parameter map into a flat map
+     *
+     * @param map The map to parse
+     * @return The flat map including all the parameters parsed from the given map
+     */
+    public static Map<String, Object> getMapParameters(Map<String, String[]> map) {
+        HashMap<String, Object> ret = new HashMap<String, Object>();
+        for (final Entry<String, String[]> parameter : map.entrySet()) {
+            final String key = parameter.getKey();
+            final String value = parameter.getValue().length > 0 ? parameter.getValue()[0] : null;
+            if (value != null) {
+                ret.put(key, value);
+            }
+        }
+        return ret;
+    }
+
+    /**
+     * Returns true if parameter map contains key
+     *
+     * @param map Map to use
+     * @param name Key value for lookup
+     * @return True if present and not empty, false if missing
+     * @throws OXException
+     */
+    public static boolean hasParameter(Map<String, String[]> map, String name) throws OXException {
+        String item = getStringParameter(map, name, false);
+        return (item != null && !item.isEmpty());
+    }
 }
