@@ -22,7 +22,7 @@ import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 public final class JsonUtil {
 
     private static final Logger LOG = LoggerFactory.getLogger(JsonUtil.class);
-    
+
     private static JsonObject toJsonObject(JSONObject jsonObject){
         JsonParser jsonParser = new JsonParser();
         return (JsonObject)jsonParser.parse(jsonObject.toString());
@@ -35,8 +35,14 @@ public final class JsonUtil {
      * @return The parsed JSON object
      */
     public static JsonObject extractObject(String webResponse) {
+        if (webResponse == null) {
+            return new JsonObject();
+        }
         int i = webResponse.indexOf("{");
         int j = webResponse.lastIndexOf("}");
+        if (i < 0 || j < 0 || i > j) {  // Not complete json string
+            return new JsonObject();
+        }
         String jsonString = webResponse.substring(i, j + 1);
         JsonParser parser = new JsonParser();
         JsonObject result = (JsonObject) parser.parse(jsonString);
@@ -68,7 +74,7 @@ public final class JsonUtil {
     public static boolean isJson(String data) {
         try {
             if (data != null && !data.isEmpty() && data.startsWith("{") && data.endsWith("}")) {
-                JsonElement parse = new JsonParser().parse(new JsonReader(new StringReader(data)));
+                new JsonParser().parse(new JsonReader(new StringReader(data)));
                 return true;
             }
             else {
@@ -125,9 +131,9 @@ public final class JsonUtil {
     public static boolean getBooleanFromJson(JsonObject json, String name) throws OXException {
         return getBooleanFromJson(json, name, false);
     }
-    
+
     public static boolean getBooleanFromJson(JSONObject json, String name) throws OXException{
-    	return getBooleanFromJson(toJsonObject(json), name);
+        return getBooleanFromJson(toJsonObject(json), name);
     }
 
     /**
@@ -178,7 +184,7 @@ public final class JsonUtil {
             throw GuardCoreExceptionCodes.JSON_ERROR.create(ex, ex.getMessage());
         }
     }
-    
+
     /**
      * Gets an integer parameter form the given JsonObject
      * @param json The JSON Object
