@@ -23,6 +23,7 @@ package com.openexchange.guard.common.util;
 
 import java.util.Locale;
 import org.apache.commons.lang.LocaleUtils;
+import org.slf4j.Logger;
 
 /**
  * {@link LocaleUtil}
@@ -32,6 +33,12 @@ import org.apache.commons.lang.LocaleUtils;
  */
 public class LocaleUtil {
 
+    /** Simple class to delay initialization until needed */
+    private static class LoggerHolder {
+
+        static final Logger LOG = org.slf4j.LoggerFactory.getLogger(LocaleUtil.class);
+    }
+
     /**
      * Parses a locale from string
      *
@@ -39,6 +46,18 @@ public class LocaleUtil {
      * @return The parsed locale
      */
     public static Locale getLocalFor(String localeString) {
-        return LocaleUtils.toLocale(localeString);
+        if (localeString == null)
+            return null;
+        localeString = localeString.replace("-", "_");
+        try {
+            return LocaleUtils.toLocale(localeString);
+        } catch (Exception e) {
+            if (localeString.length() < 6) {  // Locales should only be 5 characters
+                LoggerHolder.LOG.error("Unable to parse locale from string {}", localeString, e);
+            } else {
+                LoggerHolder.LOG.error("Invalid cookie for locale");  // Don't log the odd character string
+            }
+        }
+        return null;
     }
 }
