@@ -39,7 +39,10 @@ public enum GuardAuthExceptionCodes implements DisplayableOXExceptionCode {
     MISSING_SESSION("No valid session found.", GuardAuthExceptionMessages.MISSING_SESSION_MSG,CATEGORY_PERMISSION_DENIED,3),
     FORBIDDEN("The operation is not permitted.", GuardAuthExceptionMessages.FORBIDDEN_MSG,CATEGORY_PERMISSION_DENIED,4),
     AUTH_MISSING("Authentication parameter missing.", GuardAuthExceptionMessages.AUTH_MISSING_MSG, CATEGORY_ERROR, 5),
-    TOKEN_ERROR("Unable to get session token.", GuardAuthExceptionMessages.TOKEN_ERROR_MSG, CATEGORY_ERROR, 6);
+    TOKEN_ERROR("Unable to get session token.", GuardAuthExceptionMessages.TOKEN_ERROR_MSG, CATEGORY_ERROR, 6),
+    NOT_LOGGED_IN("User does not appear logged in.", GuardAuthExceptionMessages.NOT_LOGGED_IN, CATEGORY_ERROR, 7),
+    RECOVERY_MISSING("No recovery available", GuardAuthExceptionMessages.RECOVERY_MISSING, CATEGORY_ERROR, 8),
+    ;
 
     private String message;
     private String displayMessage;
