@@ -50,6 +50,12 @@ public final class GuardAuthExceptionMessages implements LocalizableStrings {
     /** Returned if error obtaining session token during authentication */
     public static final String TOKEN_ERROR_MSG = "Unable to obtain a session token.";
 
+    /** Action blocked, as the user does not appear to be logged in */
+    public static final String NOT_LOGGED_IN = "User does not appear to be logged in.";
+
+    /** User tried to reset/recover their password, but no recovery is available */
+    public static final String RECOVERY_MISSING = "No recovery available";
+
     /**
      * Prevent instantiation.
      */
