@@ -74,7 +74,11 @@ public enum GuardCoreExceptionCodes implements DisplayableOXExceptionCode {
 
     KEY_NOT_FOUND_PRIVATE_MASTER("Could not find the private master key of the specified key ring.", GuardCoreExceptionMessages.KEY_NOT_FOUND_PRIVATE_MASTER_MSG, CATEGORY_ERROR, 18),
 
-    KEY_NOT_FOUND_FOR_MAIL_ONLY_ERROR("Could not find key for email \"%1$s\"", GuardCoreExceptionMessages.KEY_NOT_FOUND_FOR_MAIL_ONLY_ERROR_MSG, Category.CATEGORY_ERROR, 19);
+    KEY_NOT_FOUND_FOR_MAIL_ONLY_ERROR("Could not find key for email \"%1$s\"", GuardCoreExceptionMessages.KEY_NOT_FOUND_FOR_MAIL_ONLY_ERROR_MSG, Category.CATEGORY_ERROR, 19),
+
+    UNKOWN_SIGNATURE_TYPE("Unknown signature type", GuardCoreExceptionMessages.UNKOWN_SIGNATURE_TYPE_MSG, Category.CATEGORY_ERROR, 20),
+
+    NO_USABLE_KEY_FOUND("No usable key found for \"%1$s\".  The key may be missing, expired, or revoked.  Please add another key and try again.", GuardCoreExceptionMessages.NO_USABLE_KEY_FOUND, Category.CATEGORY_ERROR, 21),
 
     ;
 
