@@ -69,4 +69,9 @@ public class GuardCoreExceptionMessages implements LocalizableStrings {
     public static final String KEY_NOT_FOUND_PRIVATE_MASTER_MSG = "Could not find the private master key of the specified key ring.";
     // Couldn't find the key for the email, followed by the address that is missing a key
     public static final String KEY_NOT_FOUND_FOR_MAIL_ONLY_ERROR_MSG = "Could not find key for email: Address \"%1$s\"";
+    // The type of email signature is unknown.
+    public static final String UNKOWN_SIGNATURE_TYPE_MSG = "Unknown signature type";
+    // User tried to encrypt something and a usable key was not found. Possibly the keys were missing, revoked, or expired and they should try to fix before encrypting.
+    public static final String NO_USABLE_KEY_FOUND = "No usable key found for \"%1$s\".  The key may be missing, expired, or revoked.  Please add another key and try again.";
+
 }
