@@ -39,7 +39,7 @@ public interface GuardConfigurationService extends Reloadable {
      * @return The string value of the property
      */
     String getProperty(String property);
-    
+
     /**
      * Fetches a property from a specified property file
      * @param fileName the name of the property file
@@ -49,58 +49,58 @@ public interface GuardConfigurationService extends Reloadable {
     String getPropertyFromFile(String fileName, String property);
 
     /**
-     * Fetches the value of specified {@link GuardProperty}
+     * Fetches the value of specified {@link GuardProp}
      *
-     * @param property The {@link GuardProperty} name to fetch
+     * @param property The {@link GuardProp} name to fetch
      * @return The string value of the property
      */
-    String getProperty(GuardProperty property);
+    String getProperty(GuardProp property);
 
     /**
-     * Fetches the value of specified {@link GuardProperty}
+     * Fetches the value of specified {@link GuardProp}
      *
-     * @param property The {@link GuardProperty} name to fetch
+     * @param property The {@link GuardProp} name to fetch
      * @return The integer value of the property
      */
-    int getIntProperty(GuardProperty property);
+    int getIntProperty(GuardProp property);
 
     /**
-     * Fetches the value of specified {@link GuardProperty}
+     * Fetches the value of specified {@link GuardProp}
      *
-     * @param property The {@link GuardProperty} name to fetch
+     * @param property The {@link GuardProp} name to fetch
      * @return The the boolean value of the property
      */
-    boolean getBooleanProperty(GuardProperty property);
+    boolean getBooleanProperty(GuardProp property);
 
     /**
-     * Fetches the value of specified {@link GuardProperty}
+     * Fetches the value of specified {@link GuardProp}
      *
-     * @param property The {@link GuardProperty} name to fetch
+     * @param property The {@link GuardProp} name to fetch
      * @param userId The user identifier
      * @param contextId The context identifier
      * @return The string value of the property
      */
-    String getProperty(GuardProperty property, int userId, int contextId);
+    String getProperty(GuardProp property, int userId, int contextId);
 
     /**
-     * Fetches the value of specified {@link GuardProperty}
+     * Fetches the value of specified {@link GuardProp}
      *
-     * @param property The {@link GuardProperty} name to fetch
+     * @param property The {@link GuardProp} name to fetch
      * @param userId The user identifier
      * @param contextId The context identifier
      * @return The integer value of the property
      */
-    int getIntProperty(GuardProperty property, int userId, int contextId);
+    int getIntProperty(GuardProp property, int userId, int contextId);
 
     /**
-     * Fetches the value of specified {@link GuardProperty}
+     * Fetches the value of specified {@link GuardProp}
      *
-     * @param property The {@link GuardProperty} name to fetch
+     * @param property The {@link GuardProp} name to fetch
      * @param userId The user identifier
      * @param contextId The context identifier
      * @return The the boolean value of the property
      */
-    boolean getBooleanProperty(GuardProperty property, int userId, int contextId);
+    boolean getBooleanProperty(GuardProp property, int userId, int contextId);
 
     /**
      * Fetches the string value of the specified OX property for the specified user in the specified context
@@ -150,16 +150,17 @@ public interface GuardConfigurationService extends Reloadable {
      * @return The directory or <code>null</code>
      */
     File getPropertyDirectory(String propertyDirectory);
-    
+
     /**
      * Gets a common server configuration
+     *
      * @param host the host to get the configuration for
-     * @param configKey the key of the configuration value to get 
+     * @param configKey the key of the configuration value to get
      * @return the configuration value for the parameters
      * @throws OXException
      */
     <T> T getServerConfiguration(String host,String configKey) throws OXException;
-    
+
     /**
      * Gets a user specific server configuration
      * @param host the host to get the configuration for
