@@ -26,7 +26,7 @@ package com.openexchange.guard.configuration;
  *
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
-public enum GuardProperty {
+public enum GuardProperty implements GuardProp {
 
     /**
      * Defines whether Guard accepts unsigned SRV records when performing HKP Server lookup via DNS.
@@ -637,6 +637,7 @@ public enum GuardProperty {
      *
      * @return the fully qualified name of the property
      */
+    @Override
     public String getFQPropertyName() {
         return fqn + name();
     }
@@ -646,6 +647,7 @@ public enum GuardProperty {
      *
      * @return the default value of this property
      */
+    @Override
     public <T extends Object> T getDefaultValue(Class<T> cls) {
         if (defaultValue.getClass().isAssignableFrom(cls)) {
             return cls.cast(defaultValue);
