@@ -2,11 +2,11 @@ package com.openexchange.guard.configuration.internal;
 
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.session.Session;
+import com.openexchange.user.User;
 
 /**
  * Register with JSLOB setting if user is to default to advanced
@@ -15,19 +15,19 @@ import com.openexchange.session.Session;
  */
 public class AdvancedUserSetting extends AbstractGuardSetting<Boolean> {
 
-	GuardConfigurationService guardConfigService;
+    GuardConfigurationService guardConfigService;
 
-	public AdvancedUserSetting(GuardConfigurationService guardConfigService) {
-		super("defaultAdvanced");
-		this.guardConfigService = guardConfigService;
-	}
+    public AdvancedUserSetting(GuardConfigurationService guardConfigService) {
+        super("defaultAdvanced");
+        this.guardConfigService = guardConfigService;
+    }
 
-	/**
-	 * Get the boolean value if the user should default to advanced.  ConfigCascade value
-	 */
-	@Override
+    /**
+     * Get the boolean value if the user should default to advanced.  ConfigCascade value
+     */
+    @Override
     protected Boolean getSettingValue(Session session, Context ctx, User user, UserConfiguration userConfig) throws OXException {
-		return guardConfigService.getBooleanProperty(GuardProperty.defaultAdvanced, user.getId(), ctx.getContextId());
+        return guardConfigService.getBooleanProperty(GuardProperty.defaultAdvanced, user.getId(), ctx.getContextId());
     }
 
 }
