@@ -26,6 +26,7 @@ import static com.openexchange.guard.common.util.FunctionalExceptionUtil.toExcep
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
@@ -83,6 +84,11 @@ public class GuardGuestServiceImpl implements GuardGuestService {
     private final ActivityTrackingService        activityTracker;
     private final GuestUpgradeStorageService     guestStorageService;
 
+    /** Simple class to delay initialization until needed */
+    private static class LoggerHolder {
+        static final Logger LOG = org.slf4j.LoggerFactory.getLogger(GuardGuestServiceImpl.class);
+    }
+
     /**
      * Initializes a new {@link GuardGuestServiceImpl}.
      *
@@ -193,33 +199,39 @@ public class GuardGuestServiceImpl implements GuardGuestService {
         //MimeMessage fullBody = fetchFull || metaData == null ? getMimeMessage(guestUser.getContextId(), itemId) : null;
         InputStream fullBodyStream = null;
         try {
-            fullBodyStream = fetchFull || metaData == null ? getMimeMessageInputStream(itemId) : null;
+            fullBodyStream = fetchFull ? getMimeMessageInputStream(itemId) : null;
         } catch (OXException ex) {  // Not found or other retrieval issue
             LOGGER.error("Error fetching email body", ex);
         }
 
-        if(metaData != null) {
-            if (fullBodyStream != null && decrypt) {
-                //Decrypt the guest MIME message
-                //Not implemented
+        boolean success = false;
+        try {
+            if (metaData != null) {
+                if (fullBodyStream != null && decrypt) {
+                    //Decrypt the guest MIME message
+                    //Not implemented
+                }
+                if (newMailFlags != null) {
+                    updateMailMessageFlags(guestIdentity, metaData, newMailFlags, set);
+                }
+                GuardGuestEmail ret =  new GuardGuestEmail(guestIdentity, itemId)
+                    .setMetaData(metaData)
+                    .setMessageStream(fetchFull ? fullBodyStream : null);
+                success = true;
+                return ret;
             }
-            if(newMailFlags != null) {
-                updateMailMessageFlags(guestIdentity, metaData, newMailFlags, set);
-            }
-            return new GuardGuestEmail(guestIdentity, itemId)
-                .setMetaData(metaData)
-                .setMessageStream(fetchFull ? fullBodyStream : null);
+            return null;
         }
-        else {
-            //Item not found
-            if(fullBodyStream != null) {
+        finally {
+            //Close the body stream if it is set but operation was not successful
+            if(fullBodyStream != null && success == false) {
                 try {
                     fullBodyStream.close();
                 } catch (IOException e) {
                     throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
                 }
+
             }
-            return null;
         }
     }
 
@@ -473,8 +485,9 @@ public class GuardGuestServiceImpl implements GuardGuestService {
         final boolean fetchBody = query.getFetchMessageBody();
         final boolean set = true;
         final UserIdentity closureIdentity = guestUser;
+        // Pull the list of emails, but do not pull the full messsage body until after filtering
         Stream<GuardGuestEmail> result = itemIds.stream()
-            .map(toExceptionThrowingFunction(itemId -> getAndUpdateMailItem(closureIdentity, itemId, fetchBody, decrypt, closureQuery.getNewMailFlags(), set))) //get the item for each ID
+            .map(toExceptionThrowingFunction(itemId -> getAndUpdateMailItem(closureIdentity, itemId, false, decrypt, closureQuery.getNewMailFlags(), set))) //get the item for each ID
             .filter(item -> item != null);//filter possible null values
 
         //Sort the result if a comparator is present
@@ -506,6 +519,19 @@ public class GuardGuestServiceImpl implements GuardGuestService {
            result = result.filter(item -> !hasFlags(item, closureQuery.getNotMailFlags()));
         }
 
+        if (fetchBody) {
+            Collection<GuardGuestEmail> guestEmails = new ArrayList<GuardGuestEmail>();
+            result.forEach(item -> {
+                try {
+                    item.setMessageStream(getMimeMessageInputStream(item.getItemId()));
+                    guestEmails.add(item);
+                } catch (OXException e) {
+                    LoggerHolder.LOG.error("Error pulling messagebody for guest email", e);
+                }
+            });
+            return guestEmails;
+        }
+
         return result.collect(Collectors.toList());
 
     }
