@@ -43,7 +43,7 @@ public class TemporaryTokenServiceImpl implements TemporaryTokenService {
     }
 
     @Override
-    public Token getToken(String tokenString) throws OXException {
+    public Token getToken(String tokenString, int userId, int cid) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
         GuardConfigurationService guardConfig = Services.getService(GuardConfigurationService.class);
 
@@ -54,7 +54,7 @@ public class TemporaryTokenServiceImpl implements TemporaryTokenService {
         try {
             stmt = connection.prepareStatement(TokenTableSql.SELECT_TOKEN_FROM_ID);
             stmt.setString(1, tokenString);
-            stmt.setInt(2, guardConfig.getIntProperty(GuardProperty.temporaryTokenLifespan));
+            stmt.setInt(2, guardConfig.getIntProperty(GuardProperty.temporaryTokenLifespan, userId, cid));
             resultSet = stmt.executeQuery();
             if (resultSet.next()) {
                 return createToken(resultSet);
