@@ -53,7 +53,7 @@ public class GuestUpgradeServiceImpl implements GuestUpgradeService {
         if (oxUserId == 0) {
             MailResolver mailResolver = new MailResolver();
             JsonObject userdat = mailResolver.resolveUser(email);
-            if (userdat.has(email)) {
+            if (userdat != null && userdat.has(email)) {
                 JsonObject user = userdat.get(email).getAsJsonObject();
                 oxUserId = user.get("uid").getAsInt();
                 oxUserCid = user.get("cid").getAsInt();
