@@ -37,6 +37,7 @@ import com.openexchange.guard.hkp.utils.CheckWhitelist;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.AccountCreationService;
 import com.openexchange.guard.keymanagement.services.RecipKeyService;
+import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 /**
  *
@@ -78,7 +79,7 @@ public class HKPIndex {
             while (keys.hasNext()) {
                 PGPPublicKey key = keys.next();
                 if (key.isMasterKey() || addSubkeys) {
-                    String id = LongUtil.longToHexString(key.getKeyID());
+                    String id = PGPKeysUtil.getFingerPrint(key.getFingerprint());
                     String algo = Integer.toString(key.getAlgorithm());
                     String keylen = Integer.toString(key.getBitStrength());
                     long cr = key.getCreationTime().getTime() / 1000;
