@@ -100,9 +100,9 @@ public class SRVHKPClientService implements HKPClientService {
      * @return a list of found PGP key rings for the given email, an empty collection if no keys were found or the email's domain has no HKP SRV set
      * @throws Exception
      */
-    private QueryResult findForSRVRecords(String serviceName, String clientToken, String email, int timeout) throws Exception {
+    private QueryResult findForSRVRecords(String serviceName, String clientToken, String email, int userId, int cid, int timeout) throws Exception {
         DNSService dnsService = Services.getService(DNSService.class);
-        DNSResult result = dnsService.getSrvs(serviceName, email);
+        DNSResult result = dnsService.getSrvs(serviceName, email, userId, cid);
 
         Collection<PGPPublicKeyRing> rings;
         int current = 0;
@@ -132,14 +132,14 @@ public class SRVHKPClientService implements HKPClientService {
      * @return A list of public keys for the email
      * @throws Exception
      */
-    private Collection<RemoteKeyResult> findAllInternal(String clientToken, String email, int timeout) throws Exception {
+    private Collection<RemoteKeyResult> findAllInternal(String clientToken, String email, int userId, int cid, int timeout) throws Exception {
 
         TimeTracker timer = new TimeTracker(timeout);
         //Searching DNS SRV records
         try {
-            QueryResult result = findForSRVRecords(HKPS_SERVICE_NAME, clientToken, email, timeout);
+            QueryResult result = findForSRVRecords(HKPS_SERVICE_NAME, clientToken, email, userId, cid, timeout);
             if (result.getResult().isEmpty()) {
-                result = findForSRVRecords(HKP_SERVICE_NAME, clientToken, email, timeout);
+                result = findForSRVRecords(HKP_SERVICE_NAME, clientToken, email, userId, cid, timeout);
             }
 
             if (result != null && result.getResult() != null && result.getResult().size() > 0) {
@@ -152,7 +152,7 @@ public class SRVHKPClientService implements HKPClientService {
             logger.error("Error querying remote HKP server form SRV record", e);
         }
         if (delegate != null) {
-            return delegate.find(clientToken, email, timer.getRemaining());
+            return delegate.find(clientToken, email, userId, cid, timer.getRemaining());
         }
         return null;
     }
@@ -167,11 +167,11 @@ public class SRVHKPClientService implements HKPClientService {
      * @return
      * @throws Exception
      */
-    private RemoteKeyResult findInternal(String clientToken, Long id, String email, int timeout) throws Exception {
+    private RemoteKeyResult findInternal(String clientToken, Long id, String email, int userId, int cid, int timeout) throws Exception {
         // To do SRV lookup, we have to search by email address to get domain
         TimeTracker timer = new TimeTracker(timeout);
         if (email != null) {
-            Collection<RemoteKeyResult> res = findAllInternal(clientToken, email, timeout);
+            Collection<RemoteKeyResult> res = findAllInternal(clientToken, email, userId, cid, timeout);
             if (res != null && !res.isEmpty()) {  //If results, then search all to see if has the key by id
                 for (PGPPublicKeyRing ring : RemoteKeyResult.getRingsFrom(res)) {
                     PGPPublicKey found = ring.getPublicKey(id);
@@ -183,25 +183,25 @@ public class SRVHKPClientService implements HKPClientService {
         }
         RemoteKeyResult result = null;
         if (delegate != null) {
-            result = delegate.find(clientToken, email, id, timer.getRemaining());
+            result = delegate.find(clientToken, email, id, userId, cid, timer.getRemaining());
         }
         return result;
 
     }
 
     @Override
-    public Collection<RemoteKeyResult> find(String clientToken, String email, int timeout) throws OXException {
+    public Collection<RemoteKeyResult> find(String clientToken, String email, int userId, int cid, int timeout) throws OXException {
         try {
-            return findAllInternal(clientToken, email, timeout);
+            return findAllInternal(clientToken, email, userId, cid, timeout);
         } catch (Exception e) {
             throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
     }
 
     @Override
-    public RemoteKeyResult find(String clientToken, String email, Long id, int timeout) throws OXException {
+    public RemoteKeyResult find(String clientToken, String email, Long id, int userId, int cid, int timeout) throws OXException {
         try {
-            return findInternal(clientToken, id, email, timeout);
+            return findInternal(clientToken, id, email, userId, cid, timeout);
         } catch (Exception e) {
             throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
