@@ -39,6 +39,19 @@ public class KeySource {
 
     private final String name;
     private final GuardProperty sourceType;
+    private final Integer trustValue;
+
+    /**
+     * Initializes a new {@link KeySource}.
+     *
+     * @param name The name of the {@link KeySource}
+     * @param trustValue A fixed trust value
+     */
+    public KeySource(String name, int trustValue) {
+        this.name = name;
+        this.trustValue = Integer.valueOf(trustValue);
+        this.sourceType = null;
+    }
 
     /**
      * Initializes a new {@link KeySource}.
@@ -49,6 +62,7 @@ public class KeySource {
     public KeySource(String name, GuardProperty sourceType) {
         this.name = name;
         this.sourceType = sourceType;
+        this.trustValue = null;
     }
 
     /**
@@ -60,15 +74,18 @@ public class KeySource {
         return name;
     }
 
-
     /**
      * Gets the trustLevel
      *
      * @return The trustLevel
      */
     public int getTrustLevel(int userId, int cid) {
-        if (sourceType == null)
+        if (trustValue != null) {
+            return trustValue.intValue();
+        }
+        if (sourceType == null) {
             return 0;
+        }
         return Services.getService(GuardConfigurationService.class).getIntProperty(sourceType, userId, cid);
     }
 
@@ -79,8 +96,9 @@ public class KeySource {
      * @throws OXException
      */
     public boolean isTrusted(int userId, int cid) throws OXException {
-        if (sourceType == null)
+        if (sourceType == null) {
             return false;
+        }
         KeySourceTrustValidatorFactory factory = Services.getService(KeySourceTrustValidatorFactory.class);
         KeySourceTrustValidator keySourceTrustValidator = factory.create(userId, cid);
         return keySourceTrustValidator.isTrusted(this, userId, cid);
