@@ -108,6 +108,9 @@ public final class PGPUtil {
      */
     public static PGPPrivateKey decodePrivate(PGPSecretKeyRing secretKeyRing, String password, String salt) throws PGPException {
         PGPSecretKey sec_key = null;
+        if (secretKeyRing == null || password == null || salt == null) {
+            return null;
+        }
         Iterator<PGPSecretKey> it = secretKeyRing.getSecretKeys();
         PGPSecretKey master = null;
         while (sec_key == null && it.hasNext()) {
