@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -54,13 +26,15 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
-import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.stream.Collectors;
 import org.bouncycastle.openpgp.PGPPublicKey;
+import com.openexchange.contact.ContactID;
 import com.openexchange.contact.ContactService;
+import com.openexchange.contact.provider.composition.IDBasedContactsAccess;
+import com.openexchange.contact.provider.composition.IDBasedContactsAccessFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
@@ -73,6 +47,7 @@ import com.openexchange.guard.keymanagement.services.PublicExternalKeyService;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.pgp.keys.parsing.PGPPublicKeyRingFactory;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
+import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Origin;
 import com.openexchange.session.Session;
 
@@ -84,23 +59,18 @@ import com.openexchange.session.Session;
  */
 public class ContactKeyServiceImpl implements ContactKeyService {
 
-    private final GuardKeyService          keyService;
-    private final PublicExternalKeyService externalKeyService;
-    private final ContactService           contactService;
-    private final GuardRatifierService     ratifierService;
+    private final ServiceLookup services;
 
     /**
      * Initializes a new {@link ContactKeyServiceImpl}.
      *
      * @param keyService The {@link GuardKeyService} to use
      * @param externalKeyService The {@link PublicExternalKeyService} to use
+     * @para contactsAccessFactory The {@link IDBasedContactsAccessFactory} to use
      * @param contactService The {@link ContactService} to use
      */
-    public ContactKeyServiceImpl(GuardKeyService keyService, PublicExternalKeyService externalKeyService, ContactService contactService, GuardRatifierService ratifierService) {
-        this.keyService = Objects.requireNonNull(keyService, "keyService must not be null");
-        this.externalKeyService = Objects.requireNonNull(externalKeyService, "externalKeyService must not be null");
-        this.contactService = Objects.requireNonNull(contactService, "contactService must not be null");
-        this.ratifierService = Objects.requireNonNull(ratifierService, "Ratifier service must not be null");
+    public ContactKeyServiceImpl(ServiceLookup services) {
+        this.services = services;
     }
 
     /**
@@ -237,7 +207,7 @@ public class ContactKeyServiceImpl implements ContactKeyService {
         };
     }
 
-    private String getKeyIdsString(GuardKeys key) {
+    private static String getKeyIdsString(GuardKeys key) {
         Iterator<PGPPublicKey> pubKeys = key.getPGPPublicKeyRing().getPublicKeys();
         StringBuilder sb = new StringBuilder();
         while (pubKeys.hasNext()) {
@@ -257,8 +227,9 @@ public class ContactKeyServiceImpl implements ContactKeyService {
      * @param contact
      * @return
      */
-    private List<String> getContactEmails(Contact contact) {
+    private List<String> getContactEmails(Contact contact) throws OXException {
         ArrayList<String> emails = new ArrayList<String>();
+        GuardRatifierService ratifierService = services.getServiceSafe(GuardRatifierService.class);
         if (ratifierService.isValid(contact.getEmail1())) {
             emails.add(contact.getEmail1());
         }
@@ -271,7 +242,7 @@ public class ContactKeyServiceImpl implements ContactKeyService {
         return emails.stream().distinct().collect(Collectors.toList());
     }
 
-    private OGPGPKeyRing toOGPGPKeyRing(int userId, int contextId, GuardKeys key) throws IOException, OXException {
+    private static OGPGPKeyRing toOGPGPKeyRing(int userId, int contextId, GuardKeys key) throws IOException, OXException {
         final boolean isGuardKey = true;
         final boolean isOwned = key.getUserid() == userId && key.getContextid() == contextId;
         return new OGPGPKeyRing(
@@ -279,6 +250,7 @@ public class ContactKeyServiceImpl implements ContactKeyService {
             PGPPublicKeyRingFactory.create(KeyExportUtil.export(key.getPGPPublicKeyRing())),
             isGuardKey).isOwned(isOwned);
     }
+
     /*
      * (non-Javadoc)
      *
@@ -286,10 +258,14 @@ public class ContactKeyServiceImpl implements ContactKeyService {
      */
     @Override
     public List<OGPGPKeyRing> getKeysForContact(int userId, int contextId, String contact_id, String folder_id) throws OXException {
-        Contact contact = contactService.getContact(createaFakeSession(userId, contextId), folder_id, contact_id);
+        IDBasedContactsAccessFactory contactsAccessFactory = services.getServiceSafe(IDBasedContactsAccessFactory.class);
+        IDBasedContactsAccess idBasedContactsAccess = contactsAccessFactory.createAccess(createaFakeSession(userId, contextId));
+        Contact contact = idBasedContactsAccess.getContact(new ContactID(folder_id, contact_id));
         List<String> emails = getContactEmails(contact);
-        List<OGPGPKeyRing> ret = emails.isEmpty() ? Collections.emptyList() : this.externalKeyService.get(userId, contextId, emails);
+        PublicExternalKeyService externalKeyService = services.getServiceSafe(PublicExternalKeyService.class);
+        List<OGPGPKeyRing> ret = emails.isEmpty() ? Collections.emptyList() : externalKeyService.get(userId, contextId, emails);
         try {
+            GuardKeyService keyService = services.getServiceSafe(GuardKeyService.class);
             for (String email : emails) {
                 GuardKeys key = keyService.getKeys(email);
                 if (key != null) {
