@@ -49,7 +49,6 @@ import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
-import com.openexchange.guard.keymanagement.commons.MasterKey;
 import com.openexchange.guard.keymanagement.commons.PGPKeys;
 import com.openexchange.guard.keymanagement.commons.exceptions.KeysExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
@@ -59,7 +58,6 @@ import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.keymanagement.services.PasswordChangeService;
 import com.openexchange.guard.keymanagement.services.RevocationReason;
 import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardKeyCreationExceptionCodes;
-import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardMasterKeyExceptionCodes;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
@@ -226,8 +224,6 @@ public class GuardKeyServiceImpl implements GuardKeyService {
      */
     @Override
     public GuardKeys storeKeys(GuardKeys key, boolean userCreated) throws OXException {
-        GuardKeys ret = null;
-
         //Getting the shard to use
         int shard = 0;
         GuardShardingService shardingService = Services.getService(GuardShardingService.class);
@@ -243,22 +239,25 @@ public class GuardKeyServiceImpl implements GuardKeyService {
         KeyTableStorage keyTableStorage = Services.getService(KeyTableStorage.class);
         keyTableStorage.insert(key, userCreated, shard);
         //retrieve the created key in order to get the userid which was created while inserting
-        ret = keyTableStorage.getKeyForEmailAndContext(key.getEmail(), key.getUserid(), key.getContextid(), shard);
-        if (ret == null) {
+        GuardKeys check = keyTableStorage.getKeyForEmailAndContext(key.getEmail(), key.getUserid(), key.getContextid(), shard);
+        if (check == null) {
             throw GuardKeyCreationExceptionCodes.KEY_CREATION_ERROR.create("Problem retrieving key from table storage after creation");
         }
+        if (key.getContextid() < 0) {  // Guests will have new userId assigned after writing to database
+            key.setUserid(check.getUserid());
+        }
         //Store key mappings
-        if (ret.getUserid() > 0) {
+        if (key.getUserid() > 0) {
             //Adding the new key to the email mapping storage
             EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
-            ogEmailStorage.insertOrUpdate(ret.getEmail(), ret.getContextid(), ret.getUserid(), shard);
+            ogEmailStorage.insertOrUpdate(key.getEmail(), key.getContextid(), key.getUserid(), shard);
 
             //Adding the new key to the PGP key mapping storage
             PGPKeysStorage keysStorage = Services.getService(PGPKeysStorage.class);
-            keysStorage.addPublicKeyIndex(ret.getContextid(), 0L, ret.getEmail(), ret.getPGPPublicKeyRing());
+            keysStorage.addPublicKeyIndex(key.getContextid(), 0L, key.getEmail(), key.getPGPPublicKeyRing());
         }
 
-        return ret;
+        return key;
     }
 
 
@@ -362,27 +361,18 @@ public class GuardKeyServiceImpl implements GuardKeyService {
             KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
             GuardKeys currentKey = ogKeyTableStorage.getCurrentKeyForUser(id, cid);
             if (currentKey != null && !Strings.isEmpty(currentKey.getRecovery())) {
-                MasterKeyService masterKeyService = Services.getService(MasterKeyService.class);
-                GuardCipherService rsaCipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.RSA);
-                MasterKey masterKeys = masterKeyService.getMasterKey(currentKey.getMasterKeyIndex(), true);
-                if (masterKeys == null) {
-                    throw GuardMasterKeyExceptionCodes.UNABLE_TO_RETIREVE_MASTER_PASSWORD.create();
-                }
-                PrivateKey privateKey = decryptPrivateKey(masterKeys.getMasterEncodedPrivate(), masterKeys.getMC(), masterKeys.getMasterSalt());
-                if (privateKey == null) {
-                    throw new Exception("Bad master key");
-                }
-                String encrhash = rsaCipherService.decrypt(currentKey.getRecovery(), privateKey);
-                if (Strings.isEmpty(encrhash)) {
-                    LOG.error("Unable to decode master key.  Possible corrupted data");
-                    throw new Exception("Bad master key");
-                }
-                GuardCipherService aesCipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
-                String rsapub = currentKey.getEncodedPublic();
-                hash = aesCipherService.decrypt(encrhash, masterKeys.getRC() + (rsapub == null ? "" : Integer.toString(rsapub.hashCode())), currentKey.getSalt());
+                KeyRecoveryService keyRecoveryService = Services.getService(KeyRecoveryService.class);
+                hash = keyRecoveryService.getRecoveryHash(
+                    currentKey.getRecovery(),
+                    currentKey.getMasterKeyIndex(),
+                    currentKey.getSalt(),
+                    currentKey.getPublicKey() == null ? "" : Integer.toString(currentKey.getEncodedPublic().hashCode()),
+                    currentKey.getUserid(),
+                    currentKey.getContextid());
             }
         } catch (Exception ex) {
             LOG.error("Error recovering the password hash for " + cid + "/" + id, ex);
+            throw OXException.general("Error recoverying password reset hash", ex);
         }
 
         return hash;
