@@ -216,14 +216,7 @@ public class KeyCreationServiceImpl implements KeyCreationService {
 
             //Creating the key generator
             PGPKeyRingGenerator keyRingGen =
-                new PGPKeyRingGenerator(PGPSignature.POSITIVE_CERTIFICATION,
-                                        masterKey,
-                                        name + " <" + email + ">",
-                                        sha1Calc,
-                                        signhashgenGenerator.generate(),
-                                        null,
-                                        new BcPGPContentSignerBuilder(masterKey.getPublicKey().getAlgorithm(),HashAlgorithmTags.SHA1),
-                                        keyEncr);
+                new PGPKeyRingGenerator(PGPSignature.POSITIVE_CERTIFICATION, masterKey, name + " <" + email + ">", sha1Calc, signhashgenGenerator.generate(), null, new BcPGPContentSignerBuilder(masterKey.getPublicKey().getAlgorithm(), HashAlgorithmTags.SHA256), keyEncr);
             keyRingGen.addSubKey(subKey, enchashgen.generate(), null);
 
             // Get the private and public encr RSA keys
@@ -247,7 +240,7 @@ public class KeyCreationServiceImpl implements KeyCreationService {
             LOG.debug("Created PGP/RSA Keys at " + start);
             return keys;
         } catch (PGPException e) {
-            throw GuardKeyCreationExceptionCodes.KEY_CREATION_ERROR.create();
+            throw GuardKeyCreationExceptionCodes.KEY_CREATION_ERROR.create(e.getMessage());
         }
     }
 }
