@@ -47,6 +47,7 @@ import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.KeyImportService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
 import com.openexchange.guard.keymanagement.services.MasterKeyService;
+import com.openexchange.guard.keymanagement.services.PasswordChangeService;
 import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardKeyImportExceptionCodes;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
@@ -200,6 +201,8 @@ public class KeyImportServiceImpl implements KeyImportService {
         newKeys.setUserid(userId);
         newKeys.setContextid(contextId);
         newKeys.setLocale(locale);
+        PasswordChangeService passwordChangeService = Services.getService(PasswordChangeService.class);
+        passwordChangeService.checkPasswordRequirements(newPassword, userId, contextId);
         final String realNewPassword = CipherUtil.getSHA(newPassword, newKeys.getSalt());
 
         //duplicate the key with the salted password
