@@ -13,6 +13,7 @@ import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
+import com.openexchange.guard.common.auth.PasswordChangedResult;
 import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
@@ -36,26 +37,24 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
     private static final Logger LOG = LoggerFactory.getLogger(PasswordChangeService.class);
 
     @Override
-    public void checkPasswordRequirements(String newpass) throws OXException {
+    public void checkPasswordRequirements(String newpass, int userId, int cid) throws OXException {
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-        int minPasswordLength = configService.getIntProperty(GuardProperty.minPasswordLength);
+        int minPasswordLength = configService.getIntProperty(GuardProperty.minPasswordLength, userId, cid);
         if (newpass.length() < minPasswordLength) {
             throw GuardChangePasswordExceptionCodes.BAD_LENGTH.create(minPasswordLength);
         }
     }
 
     @Override
-    public String changePassword (int userid, int cid, String userEmail, String oldpass, String newpass, String question, String answer, String pin, String sessionId) throws OXException {
-        JsonObject returnJson = new JsonObject();
+    public PasswordChangedResult changePassword(int userid, int cid, String userEmail, String oldpass, String newpass, String question, String answer, String pin, String sessionId) throws OXException {
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
         GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
         if (antiabuse.isBad(sessionId, configService.getIntProperty(GuardProperty.badPasswordCount))) {
             LOG.debug("Lockout for bad attempts");
-            returnJson.addProperty("auth", "Lockout");
             throw GuardAuthExceptionCodes.LOCKOUT.create();
         }
 
-        checkPasswordRequirements(newpass);
+        checkPasswordRequirements(newpass, userid, cid);
 
         // OK, logged in or guest, so we can change
         LOG.debug("change password request");
@@ -69,7 +68,6 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
                 keys = keyService.getKeys(userEmail);
             }
             if (keys == null) {
-                returnJson.addProperty("auth", "Key not found");
                 throw GuardCoreExceptionCodes.KEY_NOT_FOUND.create();
             }
         }
@@ -87,56 +85,53 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
         }
         if (keys == null) {
             LOG.info("Bad password for change");
-            returnJson.addProperty("auth", "Bad password");
             antiabuse.addBad(sessionId);
             throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
-        } else {
-            if (hasPin) {
-                secondFactor.removeSecondFactorIfSingleUse(keys.getUserid(), keys.getContextid());
-            }
-            String recovery = "";
-            boolean recoveryAvail = false;
-            KeyRecoveryService recoveryService = Services.getService(KeyRecoveryService.class);
-            if (recoveryService.checkCreateRecovery(cid, userid)) {
-                recoveryAvail = true;
-                recovery  = recoveryService.createRecovery(keys, newpass);
-            }
-            Date now = new Date();
-            keys.setLastup(new java.sql.Date(now.getTime()));
-            keyService.updateKeys(keys.getUserid(), keys.getContextid(), keys, recovery, false);
-
-            if (cid < 0) {  // Guests have question/answer to store
-                if (question.equals("") && !answer.equals("")) {
-                    question = "default";
-                }
-                if (answer != null && !answer.equals("")) {
-                    keyService.storeQuestion(keys.getUserid(), keys.getContextid(), question, answer);
-                }
-            } else {
-                if (oldQuestion == null || ((answer != null) && (answer.length() > 1))) {
-                    keyService.storeQuestion(keys.getUserid(), keys.getContextid(), question, answer);
-                }
-            }
-
-            // String sessionID = json.get("sessionID").getAsString();
-            GuardSessionService sessionService = Services.getService(GuardSessionService.class);
-            String token = sessionService.getToken(sessionId);
-            if (token == null) {
-                token = sessionService.newToken(sessionId, userid, cid);
-            }
-            // The enrypted auth data
-            JsonObject json = new JsonObject();
-            json.addProperty("user_id", keys.getUserid());
-            json.addProperty("cid", keys.getContextid());
-            json.addProperty("email", keys.getEmail());
-            json.add("encr_password", new JsonPrimitive(newpass));
-            GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_GCM);
-            returnJson.addProperty("auth", cipherService.encrypt(json.toString(), token));
-
-            returnJson.addProperty("recovery", recoveryAvail);
-            LOG.info("OK Password Change");
-            return (returnJson.toString());
         }
+        if (hasPin) {
+            secondFactor.removeSecondFactorIfSingleUse(keys.getUserid(), keys.getContextid());
+        }
+        String recovery = "";
+        boolean recoveryAvail = false;
+        KeyRecoveryService recoveryService = Services.getService(KeyRecoveryService.class);
+        if (recoveryService.checkCreateRecovery(cid, userid)) {
+            recoveryAvail = true;
+            recovery = recoveryService.createRecovery(keys, newpass);
+        }
+        Date now = new Date();
+        keys.setLastup(new java.sql.Date(now.getTime()));
+        keyService.updateKeys(keys.getUserid(), keys.getContextid(), keys, recovery, false);
+
+        if (cid < 0) {  // Guests have question/answer to store
+            if (question.equals("") && !answer.equals("")) {
+                question = "default";
+            }
+            if (answer != null && !answer.equals("")) {
+                keyService.storeQuestion(keys.getUserid(), keys.getContextid(), question, answer);
+            }
+        } else {
+            if (oldQuestion == null || ((answer != null) && (answer.length() > 1))) {
+                keyService.storeQuestion(keys.getUserid(), keys.getContextid(), question, answer);
+            }
+        }
+
+        // String sessionID = json.get("sessionID").getAsString();
+        GuardSessionService sessionService = Services.getService(GuardSessionService.class);
+        String token = sessionService.getToken(sessionId);
+        if (token == null) {
+            token = sessionService.newToken(sessionId, userid, cid);
+        }
+        GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_GCM);
+
+        // The enrypted auth data
+        JsonObject json = new JsonObject();
+        json.addProperty("user_id", keys.getUserid());
+        json.addProperty("cid", keys.getContextid());
+        json.addProperty("email", keys.getEmail());
+        json.add("encr_password", new JsonPrimitive(newpass));
+        String encryptedAuth = cipherService.encrypt(json.toString(), token);
+        LOG.info("OK Password Change");
+        return new PasswordChangedResult(encryptedAuth).withRecovery(recoveryAvail);
     }
 
     @Override
