@@ -53,4 +53,33 @@ public interface KeyRecoveryService {
      * @throws OXException
      */
     String createRecovery(GuardKeys keys, String password) throws OXException;
+
+    /**
+     * createRecovery
+     *
+     * @param masterKeyIndex Master key index for the user
+     * @param password New password
+     * @param salt User salt
+     * @param extra Any extra unique to user key data to use encrypting this recovery
+     * @param userId User ID of the user
+     * @param cid Context Id of the user
+     * @param email Email of the user (used for error messaging)
+     * @return New encrypted passowrd recovery
+     * @throws OXException
+     */
+    String createRecovery(int masterKeyIndex, String password, String salt, String extra, int userId, int cid, String email) throws OXException;
+
+    /**
+     * Get the hash from recovery
+     *
+     * @param recoveryString Stored recovery string
+     * @param masterKeyIndex Master Key index
+     * @param salt Salt for the key
+     * @param extra Any extra unique to user key data to use encrypting this recovery
+     * @param userId User Id of the user
+     * @param cid Context Id of theuser
+     * @return Passwordhash that can be used to decrypt the private key
+     * @throws OXException
+     */
+    String getRecoveryHash(String recoveryString, int masterKeyIndex, String salt, String extra, int userId, int cid) throws OXException;
 }
