@@ -946,7 +946,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
         GuardConnectionWrapper readOnly = guardDatabaseService.getReadOnly(userId, contextId, shardId);
         try {
-            return DBUtils.tableExists(readOnly.getConnection(), KeyTableSql.OG_KEY_TABLE);
+            return DBUtils.tableExists(readOnly.getConnection(), KeyTableSql.OG_KEY_TABLE, false);
         } catch (SQLException e) {
             throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         }
