@@ -44,9 +44,10 @@ public interface GuardMaintenanceMBean {
      * Reset the password for the specified user
      *
      * @param email The user's email address for which to reset the password
+     * @param type Type of crypto
      * @throws RemoteException
      */
-    void reset(String email) throws MBeanException;
+    void reset(String email, String type) throws MBeanException;
 
     /**
      * Remove the PIN for the specified user
@@ -104,8 +105,21 @@ public interface GuardMaintenanceMBean {
      */
     void importPublic(String file) throws MBeanException;
 
+    /**
+     * Imports a user private key
+     *
+     * @param type smime vs pgp
+     * @param file byte array containing key
+     * @param userId
+     * @param cid
+     * @param oldPass password for the file containing the key
+     * @param newPass new password for the user (if missing, uses oldpass)
+     */
+    void importKey(String type, byte[] file, int userId, int cid, String oldPass, String newPass) throws MBeanException;
+
     /**
      * Attempts validation and repair of guard database
+     *
      * @throws MBeanException
      */
     StringBuilder repair (boolean dryRun) throws MBeanException;
@@ -126,4 +140,14 @@ public interface GuardMaintenanceMBean {
      */
     int createMaster() throws MBeanException;
 
+    /**
+     * Imports a certificate authority for a group
+     * importCA
+     *
+     * @param file byte array containing the crt
+     * @param grpId Group Id to associate the key
+     * @throws MBeanException
+     */
+    void importCA(byte[] file, int grpId) throws MBeanException;
+
 }
