@@ -25,6 +25,7 @@ import javax.management.MBeanException;
 import javax.management.NotCompliantMBeanException;
 import javax.management.StandardMBean;
 import com.google.gson.JsonObject;
+import com.openexchange.crypto.CryptoType;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.GuardMaintenanceService;
 import com.openexchange.guard.management.maintenance.GuardMaintenanceMBean;
@@ -52,9 +53,18 @@ public class GuardMaintenanceMBeanImpl extends StandardMBean implements GuardMai
     }
 
     @Override
-    public void reset(String email) throws MBeanException {
+    public void reset(String email, String type) throws MBeanException {
         try {
-            maintenanceService.reset(email);
+            maintenanceService.reset(email, CryptoType.getTypeFromString(type));
+        } catch (OXException e) {
+            throw new MBeanException(e);
+        }
+    }
+
+    @Override
+    public void importKey(String type, byte[] file, int userId, int cid, String oldPass, String newPass) throws MBeanException {
+        try {
+            maintenanceService.importKey(type, file, userId, cid, oldPass, newPass);
         } catch (OXException e) {
             throw new MBeanException(e);
         }
@@ -162,4 +172,14 @@ public class GuardMaintenanceMBeanImpl extends StandardMBean implements GuardMai
         }
 
     }
+
+    @Override
+    public void importCA(byte[] file, int grpId) throws MBeanException {
+        try {
+            maintenanceService.importCa(file, grpId);
+        } catch (OXException e) {
+            throw new MBeanException(e);
+        }
+
+    }
 }
