@@ -30,6 +30,7 @@ import javax.mail.Part;
 import javax.mail.internet.MimeMessage;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import com.openexchange.crypto.CryptoType;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.autocrypt.AutoCryptService;
 import com.openexchange.guard.configuration.GuardConfigurationService;
@@ -113,32 +114,6 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
         this.autocryptService = Objects.requireNonNull(autocryptService, "Autocrypt Service must not be null");
     }
 
-    @Override
-    public void doEncryption (GuardParsedMimeMessage mimeMessage, int userId, int contextId, String password, OutputStream output) throws OXException {
-        try {
-            if (mimeMessage.isSign() && !mimeMessage.isEncrypt() && !mimeMessage.isDraft()) {  // not signing draft messages
-                doSigning (output, userId, contextId, password, mimeMessage);
-                return;
-            }
-            doEncrypt (output, userId, contextId, password, mimeMessage);
-        } catch (OXException e) {
-            throw e;
-        } catch (Exception e) {
-            throw MimeEncryptorExceptionCodes.SEND_EMAIL_ERROR.create(e, e.getMessage());
-        }
-    }
-
-    @Override
-    public void doDecryption(GuardParsedMimeMessage mimeMessage, int userId, int contextId, UserIdentity userIdentity, OutputStream output) throws OXException {
-        try {
-            doDecrypt(output, userId, contextId, mimeMessage, userIdentity);
-        } catch (OXException e) {
-            throw e;
-        } catch (Exception e) {
-            //TODO  Improve
-            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
-        }
-    }
 
     /**
      * Check if user has Guard-mail capability. Throw error if not
@@ -157,8 +132,10 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
             }
         }
     }
+
     /**
-     * Send email for signing only.  Not encypted
+     * Send email for signing only. Not encypted
+     * 
      * @param response
      * @param userId
      * @param contextId
@@ -166,7 +143,7 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
      * @param msg
      * @throws Exception
      */
-    private void doSigning (OutputStream output, int userId, int contextId, String password, GuardParsedMimeMessage msg) throws Exception {
+    private void doSigning(OutputStream output, int userId, int contextId, String password, GuardParsedMimeMessage msg) throws Exception {
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         checkGuardMailCapable(userId, contextId);  // Make sure has guard-mail capability to send signed emails
         GuardKeys key = keyService.getKeys(userId, contextId);
@@ -185,29 +162,18 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
      *
      * @return The new {@link ProcessMime} instance
      */
-    private ProcessMime createMimeProcessor() {
-        return new PGPProcessMime(
-            configurationService,
-            pgpCryptoService,
-            pgpMimeService,
-            pgpMimeCryptoService,
-            helpFileService,
-            guestService,
-            guardNotificationService,
-            guardMetaDataService,
-            emailStorage,
-            mailCreatorService,
-            autocryptService
-            );
+    private PGPProcessMime createMimeProcessor() {
+        return new PGPProcessMime(configurationService, pgpCryptoService, pgpMimeService, pgpMimeCryptoService, helpFileService, guestService, guardNotificationService, guardMetaDataService, emailStorage, mailCreatorService, autocryptService);
     }
 
     /**
      * Check the msg for unsupported actions
      * Currently checking for share links
+     * 
      * @param msg
      * @throws OXException
      */
-    private void checkUnsupported (GuardParsedMimeMessage msg) throws OXException {
+    private void checkUnsupported(GuardParsedMimeMessage msg) throws OXException {
         // Check for attachment link
         String[] linkHeader;
         try {
@@ -223,6 +189,7 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
 
     /**
      * Do email encryption +/- signing and send response
+     * 
      * @param response
      * @param userId
      * @param contextId
@@ -231,30 +198,57 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
      * @throws IOException
      * @throws OXException
      */
-    private void doEncrypt (OutputStream output, int userId, int contextId, String password, GuardParsedMimeMessage msg) throws IOException, OXException {
+    private void doEncrypt(OutputStream output, int userId, int contextId, String password, GuardParsedMimeMessage msg) throws IOException, OXException {
         checkUnsupported(msg);
-        ProcessMime mimeProcessor = createMimeProcessor();
+        PGPProcessMime mimeProcessor = createMimeProcessor();
         output.write(mimeProcessor.doEncrypt(msg, userId, contextId, password).getBytes(StandardCharsets.UTF_8));
     }
 
-    private void doDecrypt(OutputStream output, int userId, int contextId, GuardParsedMimeMessage msg, UserIdentity userIdentity) throws IOException, OXException, MessagingException {
-        ProcessMime mimeProcessor = createMimeProcessor();
+    private void doDecrypt(OutputStream output, GuardParsedMimeMessage msg, UserIdentity userIdentity) throws IOException, OXException, MessagingException {
+        PGPProcessMime mimeProcessor = createMimeProcessor();
         MimeMessage resultMessage = mimeProcessor.doDecrypt(msg.getMessage(), userIdentity);
         resultMessage.writeTo(output);
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.guard.mime.services.MimeEncryptionService#doDecryption(javax.mail.internet.MimeMessage, com.openexchange.guard.user.UserIdentity)
-     */
+    @Override
+    public CryptoType.PROTOCOL getCryptoType() {
+        return CryptoType.PROTOCOL.PGP;
+    }
+
+    @Override
+    public void doEncryption(GuardParsedMimeMessage mimeMessage, int userId, int contextId, String password, OutputStream output) throws OXException {
+        try {
+            if (mimeMessage.isSign() && !mimeMessage.isEncrypt() && !mimeMessage.isDraft()) {  // not signing draft messages
+                doSigning(output, userId, contextId, password, mimeMessage);
+                return;
+            }
+            doEncrypt(output, userId, contextId, password, mimeMessage);
+        } catch (OXException e) {
+            throw e;
+        } catch (Exception e) {
+            throw MimeEncryptorExceptionCodes.SEND_EMAIL_ERROR.create(e, e.getMessage());
+        }
+    }
+
+    @Override
+    public void doDecryption(GuardParsedMimeMessage mimeMessage, int userId, int contextId, UserIdentity userIdentity, OutputStream output) throws OXException {
+        try {
+            doDecrypt(output, mimeMessage, userIdentity);
+        } catch (OXException e) {
+            throw e;
+        } catch (Exception e) {
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
+        }
+    }
+
+
     @Override
     public MimeMessage doDecryption(MimeMessage mimeMessage, UserIdentity userIdentity) throws OXException {
-        ProcessMime mimeProcessor = createMimeProcessor();
+        PGPProcessMime mimeProcessor = createMimeProcessor();
         return mimeProcessor.doDecrypt(mimeMessage, userIdentity);
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.guard.mime.services.MimeEncryptionService#doDecryption(javax.mail.internet.MimeMessage, java.lang.String, com.openexchange.guard.user.UserIdentity)
-     */
+
     @Override
     public Part doDecryption(MimeMessage mimeMessage, String attachmentName, UserIdentity userIdentity) throws OXException {
         mimeMessage = doDecryption(mimeMessage, userIdentity);
