@@ -4,6 +4,7 @@ import org.slf4j.Logger;
 import com.openexchange.guard.autocrypt.AutoCryptService;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.crypto.CryptoManager;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.encryption.EncryptedItemsStorage;
 import com.openexchange.guard.guest.GuardGuestService;
@@ -40,7 +41,7 @@ public class MimeEncryptor extends HousekeepingActivator {
             OXUserService.class, EncryptedItemsStorage.class, RecipKeyService.class, PGPCryptoService.class, PGPSigningService.class, Storage.class,
             AccountCreationService.class, PGPMimeService.class, PGPMimeCryptoService.class, HelpFileService.class,
             GuardGuestEMailMetadataService.class, EmailStorage.class, GuardGuestService.class, SecondFactorService.class,
-            HtmlService.class, AutoCryptService.class };
+            HtmlService.class, AutoCryptService.class, CryptoManager.class };
     }
 
     /**
@@ -53,8 +54,7 @@ public class MimeEncryptor extends HousekeepingActivator {
 
         Services.setServiceLookup(this);
 
-        registerService(MimeEncryptionService.class,
-            new PGPMimeEncryptionService(getService(PGPCryptoService.class),
+        MimeEncryptionService pgpMimeEncr = new PGPMimeEncryptionService(getService(PGPCryptoService.class),
             getService(PGPSigningService.class),
             getService(PGPMimeCryptoService.class),
             getService(PGPMimeService.class),
@@ -65,7 +65,8 @@ public class MimeEncryptor extends HousekeepingActivator {
             getService(GuardGuestEMailMetadataService.class),
             getService(EmailStorage.class),
             getService(MailCreatorService.class),
-            getService(AutoCryptService.class)));
+            getService(AutoCryptService.class));
+        registerService(MimeEncryptionService.class, pgpMimeEncr);
         logger.info("MimeEncryptor registered.");
 
         openTrackers();
