@@ -48,7 +48,6 @@ import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.mime.encryptor.Decryptor;
 import com.openexchange.guard.mime.encryptor.Encryptor;
-import com.openexchange.guard.mime.encryptor.ProcessMime;
 import com.openexchange.guard.mime.encryptor.exceptions.MimeEncryptorExceptionCodes;
 import com.openexchange.guard.mime.encryptor.osgi.Services;
 import com.openexchange.guard.mime.encryptor.pgp.guest.PGPGuestEncryptor;
@@ -74,9 +73,9 @@ import com.openexchange.pgp.mail.PGPMimeService;
  * @author <a href="mailto:greg.hill@open-xchange.com">Greg Hill</a>
  * @since v2.8.0
  */
-public class PGPProcessMime implements ProcessMime {
+public class PGPProcessMime {
 
-    private static Logger LOG = LoggerFactory.getLogger(PGPProcessMime.class);
+    private static final Logger LOG = LoggerFactory.getLogger(PGPProcessMime.class);
 
     private final PGPCryptoService pgpCryptoService;
     private final PGPMimeCryptoService pgpMimeCryptoService;
@@ -125,7 +124,16 @@ public class PGPProcessMime implements ProcessMime {
 
     }
 
-    @Override
+    /**
+     * Encrypts a {@link GuardParsedMimeMessage} for the given user id
+     *
+     * @param msg The {@link GuardParsedMimeMessage} to encrypt
+     * @param userId The ID of the user who wants to encrypt the message
+     * @param contextId The context ID of the user who wants to encrypt the message
+     * @param password The password required for decryptiion
+     * @return The decrypted MimeMessage as raw String
+     * @throws OXException
+     */
     public String doEncrypt(GuardParsedMimeMessage msg, int userId, int contextId, String password) throws OXException {
 
         final int originalUserId = userId;
@@ -214,9 +222,7 @@ public class PGPProcessMime implements ProcessMime {
                 //Just remove the guests handled by Guard
                 return convertToString(removeRecipients(encryptedResult, guests, origMessageID));
             }
-            else {
-                throw MimeEncryptorExceptionCodes.NO_RECIPIENTS.create();
-            }
+            throw MimeEncryptorExceptionCodes.NO_RECIPIENTS.create();
         } catch (JSONException | MessagingException | IOException e) {
             LOG.error("Error encrypting email ", e);
             throw MimeEncryptorExceptionCodes.SEND_EMAIL_ERROR.create(e.getMessage());
@@ -292,16 +298,16 @@ public class PGPProcessMime implements ProcessMime {
             // Handle replies to encrypted emails when the user doesn't have Guard enabled
             // Guest replies when moved to core?
             throw MimeEncryptorExceptionCodes.SEND_NOT_AUTHORIZED.create();
-        } else {
-            if (!guardUserCapabilities.hasMinimumPermission()) {
-                throw MimeEncryptorExceptionCodes.SEND_NOT_AUTHORIZED.create();
-            }
+        }
+        if (!guardUserCapabilities.hasMinimumPermission()) {
+            throw MimeEncryptorExceptionCodes.SEND_NOT_AUTHORIZED.create();
         }
     }
 
     /**
-     * Checks to see if has Guard-Mail capability.  If so, returns true.  Of Guard only, returns false
+     * Checks to see if has Guard-Mail capability. If so, returns true. Of Guard only, returns false
      * If no Guard permissions, throws Not_Authorized
+     * 
      * @param userId
      * @param contextId
      * @return
@@ -318,12 +324,14 @@ public class PGPProcessMime implements ProcessMime {
         throw MimeEncryptorExceptionCodes.SEND_NOT_AUTHORIZED.create();
     }
 
-    /*
-     * (non-Javadoc)
+    /**
+     * Decrypts a {@link MimeMessage}
      *
-     * @see com.openexchange.guard.mime.encryptor.ProcessMime#doDecrypt(com.openexchange.guard.mime.services.GuardParsedMimeMessage, java.lang.String)
+     * @param message The {@link MimeMessage} to encrypt
+     * @param userIdentity the {@link UserIdentity} to decrypt the message for
+     * @return The encrypted {@link MimeMessage}
+     * @throws OXException
      */
-    @Override
     public MimeMessage doDecrypt(MimeMessage message, UserIdentity userIdentity) throws OXException {
 
         //Assures appropriated Guard permissions for user
@@ -344,6 +352,9 @@ public class PGPProcessMime implements ProcessMime {
             }
             return message;
         } catch (Exception e) {
+            if (e instanceof OXException) {
+                throw (OXException) e;
+            }
             throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         }
     }
@@ -364,7 +375,7 @@ public class PGPProcessMime implements ProcessMime {
      * @throws MessagingException
      * @throws IOException
      */
-    private MimeMessage removeRecipients(MimeMessage message, ArrayList<RecipKey> recipients, String origMessageID) throws MessagingException, IOException {
+    private MimeMessage removeRecipients(MimeMessage message, ArrayList<RecipKey> recipients, String origMessageID) throws MessagingException {
         if (message == null) {
             return null;
         }
