@@ -31,6 +31,8 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.IDNUtil;
+import com.openexchange.guard.email.storage.ogEmail.Email;
+import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.AccountCreationService;
 import com.openexchange.guard.keymanagement.services.RecipKeyService;
@@ -97,6 +99,16 @@ public class RecipientParser {
                     key.setLang(msg.getGuestLanguage());
                     key.setSenderCid(cid);
                     key.setSenderUserId(userId);
+                    // Check if this is an existing guest that just doesn't have any valid keys
+                    // If so, we need to reuse the userId
+                    EmailStorage emailStorage = Services.getService(EmailStorage.class);
+                    if (emailStorage != null) {
+                        Email emailLookup = emailStorage.getByEmail(email);
+                        if (emailLookup != null) {
+                            key.setCid(emailLookup.getContextId());
+                            key.setUserid(emailLookup.getUserId());
+                        }
+                    }
                 }
                 key = Services.getService(AccountCreationService.class).createUserFor(key);
                 if (key.isGuest()) {
