@@ -45,10 +45,10 @@ import com.openexchange.guard.mime.encryptor.exceptions.MimeEncryptorExceptionCo
 import com.openexchange.guard.mime.encryptor.pgp.impl.HTMLStripper;
 import com.openexchange.guard.pgpcore.services.FromHeaderVerifier;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
-import com.openexchange.guard.pgpcore.services.PGPSignatureVerificationResultUtil;
+import com.openexchange.guard.pgpcore.services.SignatureVerificationResultUtil;
 import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.pgp.core.PGPDecryptionResult;
-import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.core.SignatureVerificationResult;
 
 /**
  * {@link PGPInlineDecryptor}
@@ -64,7 +64,7 @@ public class PGPInlineDecryptor extends Decryptor {
     private final PGPCryptoService pgpCryptoService;
     private final UserIdentity userIdentity;
     private final GuardConfigurationService guardConfigService;
-    private static Logger LOG = LoggerFactory.getLogger(PGPInlineDecryptor.class);
+    private static final Logger LOG = LoggerFactory.getLogger(PGPInlineDecryptor.class);
 
     /**
      * Initializes a new {@link PGPInlineDecryptor}.
@@ -126,7 +126,7 @@ public class PGPInlineDecryptor extends Decryptor {
             PGPDecryptionResult result = pgpCryptoService.decrypt(
                 new FilteringStream(message.getInputStream(), new FilteringStream.PrintableFilter()),
                 decryptedContent, userIdentity);
-            List<PGPSignatureVerificationResult> signatureResults = result.getSignatureVerificationResults();
+            List<SignatureVerificationResult> signatureResults = result.getSignatureVerificationResults();
             message = addSignatureResults (message, signatureResults);
             message.setContent(
                 getText(decryptedContent, message.getContentType(), result.getMDCVerificationResult().isPresent()),
@@ -138,17 +138,18 @@ public class PGPInlineDecryptor extends Decryptor {
 
     /**
      * Add the results of the signature verification to the mime message
+     * 
      * @param message
      * @param signatureResults
      * @return
      * @throws MessagingException
      * @throws OXException
      */
-    private MimeMessage addSignatureResults (MimeMessage message, List<PGPSignatureVerificationResult> signatureResults) throws MessagingException, OXException {
+    private MimeMessage addSignatureResults(MimeMessage message, List<SignatureVerificationResult> signatureResults) throws MessagingException, OXException {
         message.removeHeader(GuardMimeHeaders.X_GUARD_SIGNATURE_RESULT);
         //We need to compare the FROM header of the Message with the actual User ID of the signature's issuer in order ensure that the signature was really created by the sender of the email.
         FromHeaderVerifier.verify(message, signatureResults);
-        String[] signatures = PGPSignatureVerificationResultUtil.toHeaders(signatureResults);
+        String[] signatures = SignatureVerificationResultUtil.toHeaders(signatureResults);
         for (String sig : signatures) {
             message.addHeader(GuardMimeHeaders.X_GUARD_SIGNATURE_RESULT, sig);
         }
@@ -164,8 +165,8 @@ public class PGPInlineDecryptor extends Decryptor {
      * @throws OXException
      * @throws MessagingException
      */
-    private List<PGPSignatureVerificationResult> decryptTextPart(MimeBodyPart bodyPart) throws IOException, OXException, MessagingException {
-        List<PGPSignatureVerificationResult> signatureResults = null;
+    private List<SignatureVerificationResult> decryptTextPart(MimeBodyPart bodyPart) throws IOException, OXException, MessagingException {
+        List<SignatureVerificationResult> signatureResults = null;
         if (isPGPInlineInputStream(bodyPart.getInputStream(), STREAM_INSPECTION_SIZE)) {
             //Decrypt body part and update it with the decoded data
             ByteArrayOutputStream decryptedContent = new ByteArrayOutputStream();
@@ -203,6 +204,7 @@ public class PGPInlineDecryptor extends Decryptor {
      * Simple formatting of decrypted text based on html or plaintext
      * If HTML, and no HTML formatting in body, then convert cr to <br>
      * Required as a lot of mailvelope clients simply place plaintext into alternative without formatting
+     * 
      * @param decryptedContent
      * @param type contenttype of the mail body part
      * @return
@@ -224,10 +226,9 @@ public class PGPInlineDecryptor extends Decryptor {
         if (type != null && type.contains("html")) {  // If type HTML
             if (result.contains("<br") || result.contains("<p>")) {  // If already has HTML formatting, return contents
                 return result;
-            } else {
-                // Add line breaks
-                result = result.replaceAll("\n", "<br>");
             }
+            // Add line breaks
+            result = result.replaceAll("\n", "<br>");
         }
         return result;
     }
@@ -263,11 +264,11 @@ public class PGPInlineDecryptor extends Decryptor {
      * @throws MessagingException
      * @throws OXException
      */
-    private List<PGPSignatureVerificationResult> decryptBinaryPart(MimeBodyPart bodyPart) throws IOException, MessagingException, OXException {
+    private List<SignatureVerificationResult> decryptBinaryPart(MimeBodyPart bodyPart) throws IOException, MessagingException, OXException {
         //Decrypt body part and update it with the decoded data
         ByteArrayOutputStream decryptedContent = new ByteArrayOutputStream();
         PGPDecryptionResult result = pgpCryptoService.decrypt(bodyPart.getInputStream(), decryptedContent, userIdentity);
-        List<PGPSignatureVerificationResult> signatures = result.getSignatureVerificationResults();
+        List<SignatureVerificationResult> signatures = result.getSignatureVerificationResults();
         bodyPart.setContent(decryptedContent.toByteArray(), bodyPart.getContentType());
 
         //Update PGP File extension
@@ -298,7 +299,7 @@ public class PGPInlineDecryptor extends Decryptor {
             } else {
                 //A multipart message
                 Object content = message.getContent();
-                ArrayList<PGPSignatureVerificationResult> results = new ArrayList<PGPSignatureVerificationResult>();
+                ArrayList<SignatureVerificationResult> results = new ArrayList<SignatureVerificationResult>();
                 message.setContent(parseMultipart((MimeMultipart) content, results));
                 message = addSignatureResults(message, results);
             }
@@ -311,7 +312,7 @@ public class PGPInlineDecryptor extends Decryptor {
         }
     }
 
-    private MimeMultipart parseMultipart (MimeMultipart mp, ArrayList<PGPSignatureVerificationResult> results) throws IOException, MessagingException, OXException {
+    private MimeMultipart parseMultipart(MimeMultipart mp, ArrayList<SignatureVerificationResult> results) throws IOException, MessagingException, OXException {
         MimeMultipart newPart = new MimeMultipart();
         if (mp.getContentType().contains("alternative")) {
             newPart.setSubType("alternative");
@@ -319,13 +320,16 @@ public class PGPInlineDecryptor extends Decryptor {
         for (int i = 0; i < mp.getCount(); i++) {
             MimeBodyPart bodyPart = (MimeBodyPart) mp.getBodyPart(i);
             String partContentType = bodyPart.getContentType();
+            if (partContentType == null) {
+                continue;
+            }
             if (partContentType.contains("multipart")) {
                 bodyPart.setContent(parseMultipart((MimeMultipart) bodyPart.getContent(), results));
                 newPart.addBodyPart(bodyPart);
             } else {
-                if (partContentType != null && partContentType.toLowerCase().contains("text")) {
+                if (partContentType.toLowerCase().contains("text")) {
                     //Seems like a text attachment
-                    List<PGPSignatureVerificationResult> textResult = decryptTextPart(bodyPart);
+                    List<SignatureVerificationResult> textResult = decryptTextPart(bodyPart);
                     if (textResult != null) {
                         newPart.addBodyPart(bodyPart);
                         results.addAll(textResult);
@@ -333,7 +337,7 @@ public class PGPInlineDecryptor extends Decryptor {
                 } else {
                     //Seems like a binary attachment
                     if (bodyPart.getContent() instanceof InputStream) {
-                        List<PGPSignatureVerificationResult> bodyResult = decryptBinaryPart(bodyPart);
+                        List<SignatureVerificationResult> bodyResult = decryptBinaryPart(bodyPart);
                         if (bodyResult != null) {
                             newPart.addBodyPart(bodyPart);
                             results.addAll(bodyResult);
@@ -346,6 +350,5 @@ public class PGPInlineDecryptor extends Decryptor {
         }
         return newPart;
 
-
     }
 }
