@@ -36,9 +36,9 @@ import com.openexchange.guard.mime.encryptor.pgp.impl.HTMLStripper;
 import com.openexchange.guard.pgpcore.services.FromHeaderVerifier;
 import com.openexchange.guard.pgpcore.services.PGPMimeCryptoService;
 import com.openexchange.guard.pgpcore.services.PGPMimeDecryptionResult;
-import com.openexchange.guard.pgpcore.services.PGPSignatureVerificationResultUtil;
+import com.openexchange.guard.pgpcore.services.SignatureVerificationResultUtil;
 import com.openexchange.guard.user.UserIdentity;
-import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.core.SignatureVerificationResult;
 
 /**
  * {@link PGPMimeDecryptor}
@@ -114,7 +114,7 @@ public class PGPMimeDecryptor extends Decryptor {
         try {
             final PGPMimeDecryptionResult decryptionResult = pgpMimeCryptoService.decrypt(message, userIdentity);
             final MimeMessage decodedMsg = decryptionResult.getMimeMessage();
-            final List<PGPSignatureVerificationResult> decrypt = decryptionResult.getSignatureVerificationResults();
+            final List<SignatureVerificationResult> decrypt = decryptionResult.getSignatureVerificationResults();
             checkMissingHeaders(message, decodedMsg);
             if (!decryptionResult.getMDCVerifiacionResult().isPresent()) {
                 if (guardConfigService.getBooleanProperty(GuardProperty.failForMissingMDC, userIdentity.getOXUser().getId(), userIdentity.getOXUser().getContextId())) {
@@ -131,7 +131,7 @@ public class PGPMimeDecryptor extends Decryptor {
             decodedMsg.removeHeader(GuardMimeHeaders.X_GUARD_SIGNATURE_RESULT);
             //We need to compare the FROM header of the Message with the actual User ID of the signature's issuer in order ensure that the signature was really created by the sender of the email.
             FromHeaderVerifier.verify(message, decrypt);
-            String[] signatures = PGPSignatureVerificationResultUtil.toHeaders(decrypt);
+            String[] signatures = SignatureVerificationResultUtil.toHeaders(decrypt);
             for (String sig : signatures) {
                 decodedMsg.addHeader(GuardMimeHeaders.X_GUARD_SIGNATURE_RESULT, sig);
             }
