@@ -131,6 +131,10 @@ public class Api {
         this.useragent = Strings.removeCarriageReturn(request.getHeader("User-Agent"));
     }
 
+    public Api(HttpServletRequest request) {
+        this(new OxCookie(request.getCookies()), request);
+    }
+
     /**
      * Close the httpClient and void context;
      */
