@@ -42,21 +42,23 @@ import org.apache.commons.compress.utils.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import com.openexchange.crypto.CryptoType;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.autocrypt.database.AutoCryptStorageService;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.crypto.MimeSignatureVerificationService;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.hkpclient.services.HKPClientService;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
 import com.openexchange.guard.pgpcore.services.FromHeaderVerifier;
-import com.openexchange.guard.pgpcore.services.PGPMimeSigningService;
 import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExceptionCodes;
 import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.pgp.core.PGPKeyRetrievalStrategy;
 import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 import com.openexchange.pgp.core.PGPSignatureVerifier;
+import com.openexchange.pgp.core.SignatureVerificationResult;
 import com.openexchange.tools.encoding.Base64;
 
 /**
@@ -66,9 +68,9 @@ import com.openexchange.tools.encoding.Base64;
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v7.10.2
  */
-public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
+public class PGPMimeSigningServiceImpl implements MimeSignatureVerificationService {
 
-    private static Logger LOG = LoggerFactory.getLogger(PGPMimeSigningServiceImpl.class);
+    private static final Logger LOG = LoggerFactory.getLogger(PGPMimeSigningServiceImpl.class);
     private final GuardKeyService guardKeyService;
     private final OGPGPKeysStorage keyStorage;
     private final AutoCryptStorageService autocryptService;
@@ -153,7 +155,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         return (sb.toString());
     }
 
-    private String getDecoded(InputStream stream) throws MessagingException, IOException {
+    private String getDecoded(InputStream stream) throws IOException {
         ByteArrayOutputStream out = new ByteArrayOutputStream();
         IOUtils.copy(stream, out);
         stream.close();
@@ -177,7 +179,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         return new ByteArrayInputStream(data.getBytes(StandardCharsets.UTF_8));
     }
 
-    private String getContentInlineBody(String data, boolean convert) throws OXException {
+    private String getContentInlineBody(String data, boolean convert) {
         int i = data.indexOf("----BEGIN PGP SIGNATURE");
         if (i > -1) {
             data = data.substring(0, i - 1);
@@ -203,9 +205,8 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
                 if (mp.getBodyPart(i).getContentType().contains("application/pgp-signature")) {
                     if (partData.contains("Encoding: base64")) {
                         return asStream(decodeBase64(partData));
-                    } else {
-                        return asStream(partData);
                     }
+                    return asStream(partData);
                 }
             }
         }
@@ -267,7 +268,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         return (sb.toString());
     }
 
-    private List<PGPSignatureVerificationResult> verifyMimeEmailSignature(MimeMessage message, UserIdentity userIdentity) throws OXException {
+    private List<SignatureVerificationResult> verifyMimeEmailSignature(MimeMessage message, UserIdentity userIdentity) throws OXException {
         InputStream signedData = null;
         InputStream signature = null;
         try {
@@ -291,7 +292,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         }
     }
 
-    private List<PGPSignatureVerificationResult> verifyInlineEmailSignature(String inlineData, UserIdentity userIdentity) throws OXException {
+    private List<SignatureVerificationResult> verifyInlineEmailSignature(String inlineData, UserIdentity userIdentity) throws OXException {
         InputStream signedData = requireSignedDataNotNull(extractInlineMessageFromInline(inlineData));
         InputStream signature = requireSignatureNotNull(extractInlineSignatureFromInline(inlineData));
         try {
@@ -305,9 +306,9 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         }
     }
 
-    private boolean wasVerified(List<PGPSignatureVerificationResult> results) {
+    private boolean wasVerified(List<SignatureVerificationResult> results) {
         if (results != null && results.size() > 0) {
-            for (PGPSignatureVerificationResult result : results) {
+            for (SignatureVerificationResult result : results) {
                 if (!result.isVerified()) {
                     return false;
                 }
@@ -317,9 +318,9 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         return false;
     }
 
-    private List<PGPSignatureVerificationResult> verifyInlineMessage(MimeMessage msg, UserIdentity userIdentity) throws OXException {
+    private List<SignatureVerificationResult> verifyInlineMessage(MimeMessage msg, UserIdentity userIdentity) throws OXException {
         try {
-            List<PGPSignatureVerificationResult> ret = new ArrayList<PGPSignatureVerificationResult>();
+            List<SignatureVerificationResult> ret = new ArrayList<SignatureVerificationResult>();
             Object content = msg.getContent();
             if (content instanceof String) {  // Simple text only email
                 String data = getDecoded(msg.getInputStream());
@@ -343,7 +344,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
                                 data = (String) bp.getContent();
                             }
                             try {
-                                List<PGPSignatureVerificationResult> partResult = verifyInlineEmailSignature(data, userIdentity);
+                                List<SignatureVerificationResult> partResult = verifyInlineEmailSignature(data, userIdentity);
                                 ret.addAll(partResult);
                                 if (wasVerified(partResult)) {  // If verified, clean up content
                                     bp.setContent(getContentInlineBody((String) bp.getContent(), false), bp.getContentType());
@@ -405,14 +406,19 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         return false;
     }
 
+    @Override
+    public CryptoType.PROTOCOL getCryptoType() {
+        return CryptoType.PROTOCOL.PGP;
+    }
+
     /*
      * (non-Javadoc)
      *
      * @see com.openexchange.guard.pgpcore.services.PGPMimeSigningService#verify(javax.mail.internet.MimeMessage, com.openexchange.guard.user.UserIdentity)
      */
     @Override
-    public List<PGPSignatureVerificationResult> verify(MimeMessage mimeMessage, UserIdentity user) throws OXException {
-        List<PGPSignatureVerificationResult> verificationResults;
+    public List<SignatureVerificationResult> verify(MimeMessage mimeMessage, UserIdentity user) throws OXException {
+        List<SignatureVerificationResult> verificationResults;
         if (isPGPMime(mimeMessage)) {
             verificationResults = verifyMimeEmailSignature(mimeMessage, user);
         } else {
