@@ -34,8 +34,8 @@ import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExcepti
 import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.pgp.core.PGPKeyRetrievalStrategy;
 import com.openexchange.pgp.core.PGPSignatureCreator;
-import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 import com.openexchange.pgp.core.PGPSignatureVerifier;
+import com.openexchange.pgp.core.SignatureVerificationResult;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 /**
@@ -126,7 +126,7 @@ public class PGPSigningServiceImpl implements PGPSigningService {
      * @see com.openexchange.guard.pgpcore.services.PGPSigningService#verify(java.io.InputStream, java.io.InputStream)
      */
     @Override
-    public List<PGPSignatureVerificationResult> verify(InputStream signedData, InputStream signatureData) throws OXException {
+    public List<SignatureVerificationResult> verify(InputStream signedData, InputStream signatureData) throws OXException {
         try {
             return new PGPSignatureVerifier(keyRetrievalStrategy).verifySignatures(signedData, signatureData);
         } catch (Exception e) {
