@@ -24,7 +24,7 @@ package com.openexchange.guard.pgpcore.services;
 import java.util.List;
 import javax.mail.internet.MimeMessage;
 import com.openexchange.pgp.core.MDCVerificationResult;
-import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.core.SignatureVerificationResult;
 
 /**
  * {@link PGPMimeDecryptionResult} represents the result of decrypting a PGP/MIME message.
@@ -35,7 +35,7 @@ import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 public class PGPMimeDecryptionResult {
 
     private final MimeMessage                          mimeMessage;
-    private final List<PGPSignatureVerificationResult> signatureVerificationResults;
+    private final List<SignatureVerificationResult> signatureVerificationResults;
     private final MDCVerificationResult mdcVerificationResult;
 
     /**
@@ -44,7 +44,7 @@ public class PGPMimeDecryptionResult {
      * @param mimeMessage The decrypted mimeMessage.
      * @param signatureVerificationResults The results of the signature verificaiton.
      */
-    public PGPMimeDecryptionResult(MimeMessage mimeMessage, List<PGPSignatureVerificationResult> signatureVerificationResults, MDCVerificationResult mdcVerificationResult) {
+    public PGPMimeDecryptionResult(MimeMessage mimeMessage, List<SignatureVerificationResult> signatureVerificationResults, MDCVerificationResult mdcVerificationResult) {
         this.mimeMessage = mimeMessage;
         this.signatureVerificationResults = signatureVerificationResults;
         this.mdcVerificationResult = mdcVerificationResult;
@@ -64,7 +64,7 @@ public class PGPMimeDecryptionResult {
      *
      * @return The results
      */
-    public List<PGPSignatureVerificationResult> getSignatureVerificationResults() {
+    public List<SignatureVerificationResult> getSignatureVerificationResults() {
         return signatureVerificationResults;
     }
 
