@@ -27,7 +27,7 @@ import java.util.List;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.user.UserIdentity;
-import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.core.SignatureVerificationResult;
 
 /**
  * {@link PGPSigningService}
@@ -68,5 +68,5 @@ public interface PGPSigningService {
      * @return A list of verification results
      * @throws OXException
      */
-    List<PGPSignatureVerificationResult> verify(InputStream signedData, InputStream signatureData) throws OXException;
+    List<SignatureVerificationResult> verify(InputStream signedData, InputStream signatureData) throws OXException;
 }
