@@ -80,22 +80,27 @@ public class readerPot {
         String line;
         String buffer = "";
         int lineNum = 1;
-        while ((line = br.readLine()) != null) {
-            Matcher jsmatcher = jspattern.matcher(line.trim());
-            if (jsmatcher.find()) {
-                String id = add(jsmatcher.group());
-                if (!buffer.equals("")) {
-                    addComment("#. " + buffer, id);
+        try {
+            while ((line = br.readLine()) != null) {
+                Matcher jsmatcher = jspattern.matcher(line.trim());
+                if (jsmatcher.find()) {
+                    String id = add(jsmatcher.group());
+                    if (!buffer.equals("")) {
+                        addComment("#. " + buffer, id);
+                    }
+                    addComment("#: " + filename + ":" + lineNum, id);
                 }
-                addComment("#: " + filename + ":" + lineNum, id);
+                if (line.contains("//#.")) {
+                    buffer = line.replace("//#.", "").trim();
+                } else
+                    buffer = "";
+                lineNum++;
+            }
+        } finally {
+            if (br != null) {
+                br.close();
             }
-            if (line.contains("//#.")) {
-                buffer = line.replace("//#.", "").trim();
-            } else
-                buffer = "";
-            lineNum++;
         }
-        br.close();
     }
 
     public static String add(String data) {
@@ -129,13 +134,19 @@ public class readerPot {
         try {
             System.out.println("Writing POT file");
             writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(readerLocation + "/l10n/translation.pot"), "utf-8"));
-            writer.write(header);
-            for (String key : map.keySet()) {
-                writer.write(map.get(key).getComments());
-                writer.write("msgid \"" + key + "\"\r\n");
-                writer.write("msgstr \"\"\r\n\r\n");
+            try {
+                writer.write(header);
+                for (String key : map.keySet()) {
+                    writer.write(map.get(key).getComments());
+                    writer.write("msgid \"" + key + "\"\r\n");
+                    writer.write("msgstr \"\"\r\n\r\n");
+                }
+            } finally {
+                if (writer != null) {
+                    writer.close();
+                }
             }
-            writer.close();
+
         } catch (Exception ex) {
             System.out.println(ex);
         }
