@@ -22,6 +22,7 @@
 package com.openexchange.guard;
 
 import com.google.gson.JsonObject;
+import com.openexchange.crypto.CryptoType;
 import com.openexchange.exception.OXException;
 
 /**
@@ -44,9 +45,10 @@ public interface GuardMaintenanceService {
      * Resets the specified e-mail and sends a new password to the user
      *
      * @param mail The e-mail address of the user for whom to reset the password
+     * @param type The type of crypto
      * @throws OXException
      */
-    void reset(String mail) throws OXException;
+    void reset(String mail, CryptoType.PROTOCOL type) throws OXException;
 
     /**
      * Removes the PIN for the specified guest user
@@ -86,6 +88,18 @@ public interface GuardMaintenanceService {
      */
     void importPublic(String file) throws OXException;
 
+    /**
+     * Imports a user private key
+     *
+     * @param type smime vs pgp
+     * @param file byte array containing key
+     * @param userId
+     * @param cid
+     * @param oldPass password for the file containing the key
+     * @param newPass new password for the user (if missing, uses oldpass)
+     */
+    void importKey(String type, byte[] file, int userId, int contextId, String oldPass, String newPass) throws OXException;
+
     /**
      * Repairs Guard database and checks integrity
      */
@@ -109,4 +123,14 @@ public interface GuardMaintenanceService {
      */
     int createMasterKeys() throws OXException;
 
+    /**
+     * Import certificate as certificate authority for group
+     * importCa
+     *
+     * @param file Byte array that contains the certificate
+     * @param grpId Group ID to which this certificate will be associated
+     * @return
+     */
+    boolean importCa(byte[] file, int grpId) throws OXException;
+
 }
