@@ -186,17 +186,7 @@ public class GuestLoginHandler {
                 if ((keys.getLastup() == null) && (keys.getQuestion() == null ? false : keys.getQuestion().equals("PIN"))) {
                     if (pin != null) {
                         if (pin.equals(keys.getAnswer())) {
-                            returndata = cipherService.encrypt(
-                                    AuthUtils.createAuthJson(
-                                        keys.getUserid(),
-                                        keys.getContextid(),
-                                    0,
-                                    0,
-                                        keys.getEmail(),
-                                        ENCR_PASSWORD_AUTH_FIELD_NAME,
-                                        json.has("encr_password") ? json.get("encr_password").getAsString() : "",
-                                        json.has("language") ? json.get("language").getAsString() : "").toString(),
-                                    token);
+                            returndata = cipherService.encrypt(AuthUtils.createAuthJson(keys.getUserid(), keys.getContextid(), 0, 0, keys.getEmail(), ENCR_PASSWORD_AUTH_FIELD_NAME, json.has("encr_password") ? json.get("encr_password").getAsString() : "", json.has("language") ? json.get("language").getAsString() : "").toString(), token);
                         } else {
                             returndata = "Bad";
                             antiabuse.addBad(username);
@@ -207,17 +197,7 @@ public class GuestLoginHandler {
                     }
                 } else {
                     antiabuse.report(AntiAbuseUtils.getReportParameter(true, request, username, password));
-                    returndata = cipherService.encrypt(
-                            AuthUtils.createAuthJson(
-                                keys.getUserid(),
-                                keys.getContextid(),
-                            0,
-                            0,
-                                keys.getEmail(),
-                                ENCR_PASSWORD_AUTH_FIELD_NAME,
-                                json.has("encr_password") ? json.get("encr_password").getAsString() : "",
-                                json.has("language") ? json.get("language").getAsString() : "").toString(),
-                            token);
+                    returndata = cipherService.encrypt(AuthUtils.createAuthJson(keys.getUserid(), keys.getContextid(), 0, 0, keys.getEmail(), ENCR_PASSWORD_AUTH_FIELD_NAME, json.has("encr_password") ? json.get("encr_password").getAsString() : "", json.has("language") ? json.get("language").getAsString() : "").toString(), token);
                 }
             }
 
