@@ -21,8 +21,8 @@
 
 package com.openexchange.guard.auth;
 
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.osgi.Services;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.session.GuardSessionService;
 
 /**
