@@ -21,18 +21,24 @@
 
 package com.openexchange.guard.demo;
 
+import java.util.HashSet;
 import java.util.List;
+import java.util.Optional;
+import java.util.Set;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
+import com.openexchange.guard.certificatemanagement.commons.SmimeKeys;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.demo.exceptions.DemoExceptionCodes;
 import com.openexchange.guard.email.storage.ogEmail.Email;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.smime.SmimeKeyService;
 import com.openexchange.guard.support.UserDeleter;
+import com.openexchange.session.UserAndContext;
 
 /**
  * This class provides functionalities which are useful for running OX Guard in
@@ -57,39 +63,78 @@ public class DemoUtil {
             throw DemoExceptionCodes.DEMO_MODE_DISABLED_ERROR.create();
         }
     }
-
+    
     /**
-     * Internal method to delete a user's Guard key by email
+     * Internal method to resolve a {@link UserAndContext} from the given email
      *
-     * @param email The emai object of the user
+     * @param email The email to revolve the {@link UserAndContext} for
+     * @return The {@link UserAndContext} for the given email, or null if no {@link UserAndContext} could be resolved
      * @throws OXException
      */
-    private void deleteByEmail(Email email) throws OXException {
-        if (email != null) {
-            int userId = email.getUserId();
-            int contextId = email.getContextId();
-            new UserDeleter().delete(userId, contextId);
-        } else {
-            throw DemoExceptionCodes.UNKNOWN_EMAIL_ERROR.create(email);
+    private UserAndContext getUserAndContext(String email) throws OXException {
+        //Check for PGP
+        EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
+        Email emailObject = ogEmailStorage.getByEmail(email);
+        if (emailObject != null) {
+            return UserAndContext.newInstance(emailObject.getUserId(), emailObject.getContextId());
         }
+
+        //Check for S/MIME
+        List<SmimeKeys> keys = Services.getService(SmimeKeyService.class).getKeys(email);
+        Optional<SmimeKeys> smimeKey = keys.stream().filter(k -> k.isLocal()).findAny();
+        if (smimeKey.isPresent()) {
+            return UserAndContext.newInstance(smimeKey.get().getUserId(), smimeKey.get().getContextId());
+        }
+
+        return null;
+    }
+    
+    /**
+     * Internal method to get a list of {@link UserAndContext} representing all known OX Guard users
+     *
+     * @return A list of {@link UserAndContext} representing all known OX Guard users
+     * @throws OXException
+     */
+    private Set<UserAndContext> getAllUserAndContext() throws OXException {
+        final List<Email> allEmails = Services.getService(EmailStorage.class).getEmails();
+        final List<SmimeKeys> allKeys = Services.getService(SmimeKeyService.class).getPublicKeys();
+        final HashSet<UserAndContext> ret = new HashSet<UserAndContext>(allEmails.size() + allKeys.size());
+
+        for (Email email : allEmails) {
+            ret.add(UserAndContext.newInstance(email.getUserId(), email.getContextId()));
+        }
+        for (SmimeKeys key : allKeys) {
+            ret.add(UserAndContext.newInstance(key.getUserId(), key.getContextId()));
+        }
+        return ret;
     }
 
     /**
-     * Deletes all known OX Guard keys  WITHOUT creating any backups
+     * Internal method to delete a user's Guard Key by ID
+     *
+     * @param userId The ID of the user
+     * @param contextId The ID of the context
+     * @throws OXException
+     */
+    private void deleteById(int userId, int contextId) throws OXException {
+        new UserDeleter().delete(userId, contextId);
+    }
+
+    /**
+     * Deletes all known OX Guard keys WITHOUT creating any backups
      * (com.openexchange.guard.demo has to be "true")
+     * 
      * @throws OXException
      */
     public int deleteAllUserKeys() throws OXException {
+        //ensure OX Guard is running in demo mode; or throw an exception
         assertDemoMode();
 
-        EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
-        List<Email> allEmails = ogEmailStorage.getEmails();
-        int count = 0;
-        for(Email email : allEmails) {
-            deleteByEmail(email);
-            count++;
+        final Set<UserAndContext> users = getAllUserAndContext();
+        for (UserAndContext user : users) {
+            deleteById(user.getUserId(), user.getContextId());
         }
-        return count;
+        return users.size();
     }
 
     /**
@@ -103,12 +148,30 @@ public class DemoUtil {
         //ensure OX Guard is running in demo mode; or throw an exception
         assertDemoMode();
 
-        EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
-        Email emailObject = ogEmailStorage.getByEmail(email);
-        if(emailObject != null) {
-            deleteByEmail(emailObject);
+        UserAndContext user = getUserAndContext(email);
+        if (user != null) {
+            deleteById(user.getUserId(), user.getContextId());
+        } else {
+            throw DemoExceptionCodes.UNKNOWN_EMAIL_ERROR.create(email);
         }
-        else {
+    }
+
+    /**
+     * Resets the Anti-Abuse entry for a given email
+     *
+     * @param email The email of the user to reset the Anti-Abuse entry for
+     * @throws OXException
+     */
+    public void resetBad(String email) throws OXException {
+        //ensure OX Guard is running in demo mode; or throw an exception
+        assertDemoMode();
+
+        UserAndContext user = getUserAndContext(email);
+        if (user != null) {
+            GuardAntiAbuseService antiAbuseService = Services.getService(GuardAntiAbuseService.class);
+            final String username = user.getUserId() + "-" + user.getContextId();
+            antiAbuseService.removeBad(username);
+        } else {
             throw DemoExceptionCodes.UNKNOWN_EMAIL_ERROR.create(email);
         }
     }
@@ -121,7 +184,7 @@ public class DemoUtil {
      * @throws OXException
      */
     public void resetBad(int contextId, int userId) throws OXException {
-
+        //ensure OX Guard is running in demo mode; or throw an exception
         assertDemoMode();
 
         GuardAntiAbuseService antiAbuseService = Services.getService(GuardAntiAbuseService.class);
