@@ -24,7 +24,6 @@ package com.openexchange.guard.handler;
 import javax.servlet.http.HttpServletRequest;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
-import com.openexchange.osgi.annotation.SingletonService;
 
 /**
  * {@link ResponseHandler}
@@ -32,7 +31,7 @@ import com.openexchange.osgi.annotation.SingletonService;
  * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
  * @since v2.4.0
  */
-@SingletonService
+
 public interface ResponseHandler {
 
     JsonObject getJsonAndDecodeEncryptedPasswords(HttpServletRequest request, int userId, int cid) throws OXException;
