@@ -30,8 +30,13 @@ import com.openexchange.context.ContextService;
 import com.openexchange.guard.GuardMaintenanceService;
 import com.openexchange.guard.activity.ActivityTrackingService;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
+import com.openexchange.guard.auth.AuthenticationService;
+import com.openexchange.guard.auth.AuthenticationServiceRegistry;
+import com.openexchange.guard.auth.AuthenticationServiceRegistryImpl;
+import com.openexchange.guard.auth.PGPAuthenticationService;
 import com.openexchange.guard.autocrypt.AutoCryptService;
 import com.openexchange.guard.autocrypt.database.AutoCryptStorageService;
+import com.openexchange.guard.certificatemanagement.RecipCertificateService;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
@@ -44,6 +49,7 @@ import com.openexchange.guard.cron.DailyTaskScheduler;
 import com.openexchange.guard.cron.GuestCleanupTask;
 import com.openexchange.guard.cron.PopulateKeyCacheTask;
 import com.openexchange.guard.cron.ResetExposedKeysTask;
+import com.openexchange.guard.crypto.CryptoManager;
 import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.GuardShardingService;
 import com.openexchange.guard.dns.DNSService;
@@ -85,7 +91,6 @@ import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.oxapi.pooling.HttpConnectionPoolService;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.pgpcore.services.PGPKeySigningService;
-import com.openexchange.guard.pgpcore.services.PGPMimeSigningService;
 import com.openexchange.guard.pgpcore.services.PGPPacketService;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
@@ -95,6 +100,7 @@ import com.openexchange.guard.servlets.GuardServlets;
 import com.openexchange.guard.session.GuardSessionService;
 import com.openexchange.guard.settings.GlobalSettingsStorage;
 import com.openexchange.guard.sharing.SharingService;
+import com.openexchange.guard.smime.SmimeKeyService;
 import com.openexchange.guard.storage.Storage;
 import com.openexchange.guard.storage.cache.FileCacheStorage;
 import com.openexchange.guard.translation.GuardTranslationService;
@@ -127,17 +133,17 @@ public class GuardServiceActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { HttpService.class, SignalHttpApiAvailabilityService.class,
+        return new Class<?>[] { HttpService.class, SignalHttpApiAvailabilityService.class, CryptoManager.class,
             GuardConfigurationService.class, MasterKeyService.class, TimerService.class, GuardTranslationService.class,
             GuardRatifierService.class, GuardCipherFactoryService.class, GuardDatabaseService.class, GuardSessionService.class,
-            KeyCacheStorage.class, RecipKeyService.class, MailCreatorService.class, DNSService.class, GlobalSettingsStorage.class,
+            KeyCacheStorage.class, RecipKeyService.class, RecipCertificateService.class, MailCreatorService.class, DNSService.class, GlobalSettingsStorage.class,
             GuardNotificationService.class, GuardAntiAbuseService.class, GuardKeyService.class, EmailStorage.class,
             GuardShardingService.class, KeyTableStorage.class, PGPKeysStorage.class, EncryptedItemsStorage.class, OGPGPKeysStorage.class,
             DeletedKeysStorage.class, Storage.class, GuardUpdateService.class, GuestUpgradeService.class, HKPClientService.class,
-            PGPCryptoService.class, PGPSigningService.class, PGPMimeSigningService.class, TokenAuthenticationService.class, FileCacheStorage.class, RemoteKeyCacheStorage.class,
+            PGPCryptoService.class, PGPSigningService.class, TokenAuthenticationService.class, FileCacheStorage.class, RemoteKeyCacheStorage.class,
             GuestResetService.class, TemporaryTokenService.class, KeyCreationService.class, OXUserService.class, KeyRecoveryService.class,
             PasswordChangeService.class, AccountCreationService.class, PublicExternalKeyService.class, KeyImportService.class, ContextService.class,
-            MimeEncryptionService.class, PGPKeyRingParser.class, ImportSystemPublicKey.class, PGPPacketService.class, GuardGuestService.class,
+            PGPKeyRingParser.class, ImportSystemPublicKey.class, PGPPacketService.class, GuardGuestService.class,
             PGPKeySigningService.class, ContactKeyService.class, SharingService.class, GuardGuestEMailMetadataService.class,
             GuestConverterService.class, GuestRedirectorService.class, GuestLookupService.class, SecondFactorService.class, GuardKeysUpdater.class,
             AutoCryptService.class, AutoCryptStorageService.class };
@@ -162,7 +168,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
         GuardVersion.loadGuardVersion();
 
         // Register the maintenance service
-        GuardMaintenanceService maintenanceService = new GuardMaintenanceServiceImpl();
+        GuardMaintenanceService maintenanceService = new GuardMaintenanceServiceImpl(this);
         registerService(GuardMaintenanceService.class, maintenanceService);
         trackService(GuardMaintenanceService.class);
 
@@ -170,6 +176,14 @@ public class GuardServiceActivator extends HousekeepingActivator {
         registerService(ResponseHandler.class, new ResponseHandlerImpl(this));
         trackService(ResponseHandler.class);
 
+        AuthenticationServiceRegistryImpl registry = new AuthenticationServiceRegistryImpl();
+        registerService(AuthenticationServiceRegistry.class, registry);
+        track(AuthenticationService.class, new AuthenticationTracker(context, registry));
+        registerService(AuthenticationService.class, new PGPAuthenticationService());
+
+        trackService(MimeEncryptionService.class);
+        trackService(SmimeKeyService.class);
+
         openTrackers();
 
         Services.getService(GuardUpdateService.class).createMasterKeysIfNecessary();
@@ -206,6 +220,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
 
         //Registering the OX Guard servlets
         GuardServlets.registerServlets(this);
+
     }
 
     /*
