@@ -61,6 +61,7 @@ public class GuardErrorResponseRenderer {
 
     /**
      * Initializes a new {@link GuardErrorResponseRenderer}.
+     * 
      * @param errorResponseCode The response code which will be send to the client in case of an error
      * @param wrapErrorInArray True in order to wrap the error in an array (legacy API), false otherwise
      */
@@ -102,7 +103,7 @@ public class GuardErrorResponseRenderer {
      * @param request the client's request
      * @return true, if the client requested a JSON response, false otherwise
      */
-    private boolean isRespondJSON(final HttpServletRequest request) {
+    protected boolean isRespondJSON(final HttpServletRequest request) {
         return Boolean.parseBoolean(request.getParameter("respondWithJSON"));
     }
 
@@ -133,7 +134,7 @@ public class GuardErrorResponseRenderer {
         Object[] logArgsArray = e.getLogArgs();
         if (logArgsArray != null) {
             for (Object logArgs : logArgsArray) {
-                if(logArgs != null) {
+                if (logArgs != null) {
                     JsonPrimitive displayArgParam = new JsonPrimitive(logArgs.toString());
                     errorParams.add(displayArgParam);
                 }
@@ -256,12 +257,11 @@ public class GuardErrorResponseRenderer {
         } else {
             //Writing error as plain JSON
             JsonElement ret = null;
-            if(this.wrapErrorInArray) {
+            if (this.wrapErrorInArray) {
                 JsonArray errorObjects = new JsonArray();
                 errorObjects.add(errorObject);
                 ret = errorObjects;
-            }
-            else {
+            } else {
                 ret = errorObject;
             }
             PrintWriter writer = null;
