@@ -24,30 +24,38 @@ package com.openexchange.guard.servlets;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import java.util.Map;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.json.JSONObject;
 import org.slf4j.event.Level;
+import com.google.gson.JsonObject;
 import com.openexchange.antiabuse.AllowParameters;
+import com.openexchange.crypto.CryptoType;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.auth.AuthUtils;
+import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
+import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseWrapper;
 import com.openexchange.guard.keymanagement.commons.antiabuse.KeyAntiAbuseWrapper;
 import com.openexchange.guard.keymanagement.commons.antiabuse.UserAntiAbuseWrapper;
 import com.openexchange.guard.logging.GuardLogProperties;
 import com.openexchange.guard.logging.LoggingHelper;
+import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.oxapi.Api;
+import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.servlets.authentication.AuthenticationDataExtractor;
 import com.openexchange.guard.servlets.authentication.GuardAuthenticationHandler;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.authentication.GuestSessionValidator;
 import com.openexchange.guard.servlets.authentication.RestSessionValidator;
 import com.openexchange.guard.servlets.authentication.UserIdentityJsonParser;
@@ -58,6 +66,7 @@ import com.openexchange.guard.translation.GuardTranslationService;
 import com.openexchange.guard.translation.GuardTranslator;
 import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.i18n.Translator;
+import com.openexchange.java.Strings;
 
 /**
  * Represents an OX Guard HTTP action
@@ -68,8 +77,11 @@ import com.openexchange.i18n.Translator;
 public abstract class GuardServletAction {
 
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(GuardServletAction.class);
-
     private static final String WWW_AUTHENTICATE_HEADER = "WWW-Authenticate";
+
+    protected static final String CRYPTO_TYPE_PARAMETER = "type";
+    protected static final CryptoType.PROTOCOL DEFAULT_CRYPTO_TYPE = CryptoType.PROTOCOL.PGP;
+
     private List<GuardAuthenticationHandler> authenticationHandlers;
     private GuardErrorResponseRenderer errorResponseRenderer;
 
@@ -296,9 +308,7 @@ public abstract class GuardServletAction {
      */
     protected AntiAbuseWrapper getAntiAbuseWrapper(GuardKeys keys, AllowParameters allowParams) throws OXException {
         GuardAntiAbuseService antiAbuse = Services.getService(GuardAntiAbuseService.class);
-        return new KeyAntiAbuseWrapper(antiAbuse,
-            keys,
-            allowParams);
+        return new KeyAntiAbuseWrapper(antiAbuse, keys, allowParams);
     }
 
     /**
@@ -313,8 +323,11 @@ public abstract class GuardServletAction {
      */
     protected AntiAbuseWrapper getAntiAbuseWrapper(AllowParameters allowParams) throws OXException {
         GuardAntiAbuseService antiAbuse = Services.getService(GuardAntiAbuseService.class);
-        return new UserAntiAbuseWrapper(antiAbuse,
-            allowParams);
+        return new UserAntiAbuseWrapper(antiAbuse, allowParams);
+    }
+
+    protected AntiAbuseWrapper getAntiAbuseWrapper(HttpServletRequest request, GuardUserSession userSession, String password) throws OXException {
+        return getAntiAbuseWrapper(AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(), userSession.getContextId(), password));
     }
 
     /**
@@ -341,6 +354,18 @@ public abstract class GuardServletAction {
         return requireOrReturn(userIdentity, require);
     }
 
+    /**
+     * Parses a {@link UserIdentity} from the given {@link HttpServletRequest}, or throws an Exception if the request does not contain enough information for creating a {@link UserIdentity} object.
+     * 
+     * @param request The request to parse the {@link UserIdentity} from.
+     * @param guardUserSession The {@link GuardUserSession} to obtain user- and context-id from
+     * @return The parsed {@link UserIdentity}
+     * @throws OXException
+     */
+    protected UserIdentity requireUserIdentityFrom(HttpServletRequest request, GuardUserSession guardUserSession) throws OXException {
+        return requireUserIdentityFrom(request, guardUserSession.getUserId(), guardUserSession.getContextId());
+    }
+
     /**
      * Parses a {@link UserIdentity} from the given {@link JSONObject}
      *
@@ -414,6 +439,102 @@ public abstract class GuardServletAction {
         return new GuardTranslator(Services.getService(GuardTranslationService.class), guardUserSession.getLocale());
     }
 
+    /**
+     * Return parameters that were sent with the HTTPServletReqeuest
+     *
+     * @param request
+     * @return Map<String, String[]> of parameters
+     */
+    protected static Map<String, String[]> getHttpParameters(HttpServletRequest request) {
+        return request.getParameterMap();
+    }
+
+    /**
+     * Get the first value from parameter map for parameter name
+     *
+     * @param map Map of parameters
+     * @param parameter Parameter name to find
+     * @return First value, or null if empty
+     */
+    protected static String getParameter(Map<String, String[]> map, String parameter) {
+        if (map.containsKey(parameter)) {
+            String[] vals = map.get(parameter);
+            if (vals.length > 0) {
+                return vals[0];
+            }
+        }
+        return null;
+    }
+
+    /**
+     * Pulls the json Object from request data
+     * Verifies the user is logged into the UI if doVerification true
+     *
+     * @param request The HTTPRequest
+     * @param userSession Guard user session
+     * @param doVerification If true, MW will be queried to verify user logged in
+     * @return JsonObject (may be null). Error if user not logged in.
+     * @throws OXException
+     */
+    protected static JsonObject getJsonVerifyLogin(HttpServletRequest request, GuardUserSession userSession, boolean doVerification) throws OXException {
+        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request, userSession.getUserId(), userSession.getContextId());
+        if (doVerification) {
+            // if ox member, verify actually logged in to ui
+            if (userSession.getGuardContextId() > 0) {
+                Api ap = new Api(new OxCookie(request.getCookies()), request);
+                if (ap.verifyLogin() == false) {
+                    throw GuardAuthExceptionCodes.NOT_LOGGED_IN.create();
+                }
+            }
+        }
+        return json;
+    }
+
+    protected static boolean hasCryptoType(HttpServletRequest request) {
+        return ServletUtils.hasParameter(request, CRYPTO_TYPE_PARAMETER);
+    }
+
+    /**
+     * Convenience method to obtain the {@link CryptoType.PROTOCOL} from the given request.
+     * 
+     * <p>
+     * The "crypto type" is used in many situations to differentiate between cryptographic methods supported in OX Guard.
+     * (for example PGP vs S/MIME)
+     * </p>
+     * 
+     * @param request The {@link HttpServletRequest} to pull the crypto type from
+     * @return The {@link CryptoType.PROTOCOL} type extracted from the given request, or, if missing, the default "crypto type".
+     */
+    protected static CryptoType.PROTOCOL getCryptoType(HttpServletRequest request) {
+        String type = ServletUtils.getStringParameter(request, CRYPTO_TYPE_PARAMETER);
+        return Strings.isEmpty(type) ? DEFAULT_CRYPTO_TYPE /* GUARD specific default */ : CryptoType.getTypeFromString(type);
+    }
+
+    /**
+     * Convenience method to obtain the {@link CryptoType.PROTOCOL} from the given {@link GuardParsedMimeMessage}
+     *
+     * @param parsedMimeMessage The message to obtain the type from
+     * @return The type parsed from the given {@link GuardParsedMimeMessage}, or the default type if no such type was found within the parsed message
+     */
+    protected static CryptoType.PROTOCOL getCryptoType(GuardParsedMimeMessage parsedMimeMessage) {
+        return parsedMimeMessage.getType() != null ? parsedMimeMessage.getType() : DEFAULT_CRYPTO_TYPE;
+    }
+
+    /**
+     * Convenience method to obtain the {@link CryptoType.PROTOCOL} either from the given {@link HttpServletRequest} or the given {@link GuardParsedMimeMessage}
+     *
+     * @param request The request
+     * @param parsedMimeMessage The message
+     * @return The crypto type from the given request, if present, or, otherwise, the crypto type from the given message. Returns the default crypto type
+     *         if neither the request nor the message has a crypto type defined.
+     */
+    protected static CryptoType.PROTOCOL getCryptoType(HttpServletRequest request, GuardParsedMimeMessage parsedMimeMessage){
+        if(hasCryptoType(request)) {
+            return getCryptoType(request);
+        }
+        return parsedMimeMessage.getType() != null ? parsedMimeMessage.getType() : DEFAULT_CRYPTO_TYPE;
+    }
+
     /**
      * Template method which allows implementation of the action execution by subclasses
      *
