@@ -21,6 +21,8 @@
 
 package com.openexchange.guard.servlets.authentication;
 
+import static com.openexchange.guard.servlets.authentication.ConnectionInformationFactory.createConnectionInformationFrom;
+import static com.openexchange.guard.servlets.util.ServletLocaleUtil.getLocaleFor;
 import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServletRequest;
 import org.slf4j.Logger;
@@ -31,10 +33,9 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.session.GuardSessionService;
-import static com.openexchange.guard.servlets.util.ServletLocaleUtil.*;
-import static com.openexchange.guard.servlets.authentication.ConnectionInformationFactory.*;
 
 /**
  * {@link GuestSessionValidator}
@@ -74,7 +75,10 @@ public class GuestSessionValidator implements SessionValidator {
 
                 if (token != null) {
                     GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_GCM);
-                    String userdata = cipherService.decrypt(authToken, token);
+                    if (authToken.contains("!")) {
+                        authToken = authToken.substring(authToken.indexOf("!") + 1);
+                    }
+                    String userdata = cipherService.decrypt(authToken.substring(1), token);
                     if (userdata != null && !userdata.isEmpty()) {
                         Gson json = new Gson();
                         JsonObject userDataJson = json.fromJson(userdata, JsonObject.class);
