@@ -25,13 +25,13 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.common.util.JsonUtil;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.inputvalidation.RangeInputValidator;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.support.UserDeleter;
 
 /**
