@@ -24,10 +24,10 @@ package com.openexchange.guard.servlets.demo;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.demo.DemoUtil;
 import com.openexchange.guard.inputvalidation.EmailValidator;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 
 /**
  * Deletes all keys for a certain OX Guard user without creating backups - Useful for resetting users in a demo or test environment
