@@ -21,12 +21,13 @@
 
 package com.openexchange.guard.servlets.demo;
 
+import static com.openexchange.java.Autoboxing.I;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.demo.DemoUtil;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 
 
 /**
@@ -45,7 +46,7 @@ public class ResetAllAction extends GuardServletAction {
         //Deleting ALL known Guard keys for the given email
         ServletUtils.sendObject(response, new Object() {
             @SuppressWarnings("unused")
-            public Integer deletedUserCount = new DemoUtil().deleteAllUserKeys();
+            public Integer deletedUserCount = I(new DemoUtil().deleteAllUserKeys());
         });
     }
 }
