@@ -24,14 +24,10 @@ package com.openexchange.guard.servlets.demo;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.demo.DemoUtil;
-import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.inputvalidation.EmailValidator;
-import com.openexchange.guard.keymanagement.commons.GuardKeys;
-import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 
 
 /**
@@ -48,13 +44,6 @@ public class ResetAntiAbuseAction extends GuardServletAction {
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
         String email = new EmailValidator().assertInput(ServletUtils.getStringParameter(request, "email", true), "email");
-        GuardKeyService service = Services.getService(GuardKeyService.class);
-        GuardKeys keys = service.getKeys(email);
-        if(keys != null) {
-            new DemoUtil().resetBad(keys.getContextid(), keys.getUserid());
-        }
-        else {
-            throw GuardCoreExceptionCodes.KEY_NOT_FOUND.create();
-        }
+        new DemoUtil().resetBad(email);
     }
 }
