@@ -35,11 +35,11 @@ import com.fasterxml.jackson.core.JsonParseException;
 import com.fasterxml.jackson.databind.JsonMappingException;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.guest.GuardGuestEmail;
 import com.openexchange.guard.guest.GuardGuestService;
 import com.openexchange.guard.osgi.Services;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
 import com.openexchange.guard.servlets.guest.responses.GuestEmailsResponse;
