@@ -28,6 +28,7 @@ import org.apache.commons.fileupload.FileItem;
 import org.json.JSONObject;
 import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
@@ -38,7 +39,6 @@ import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseAction;
 import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseWrapper;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
 import com.openexchange.guard.user.UserIdentity;
