@@ -23,9 +23,9 @@ package com.openexchange.guard.servlets.guest;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 
 /**
  * Gets the question which is required for a guest password reset
