@@ -21,12 +21,15 @@
 
 package com.openexchange.guard.servlets.guest;
 
+import static com.openexchange.java.Autoboxing.B;
 import java.io.InputStream;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.google.gson.JsonObject;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
+import com.openexchange.guard.common.auth.PasswordChangedResult;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
@@ -39,7 +42,6 @@ import com.openexchange.guard.keymanagement.services.PasswordChangeService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.guest.exceptions.GuestServletExceptionCodes;
 import com.openexchange.guard.storage.Storage;
 
@@ -51,6 +53,19 @@ import com.openexchange.guard.storage.Storage;
  */
 public class GuestFirstPasswordAction extends GuardServletAction {
 
+    /**
+     * Converts the given{@link PasswordChangedResult} to JSON
+     *
+     * @param result The result to convert
+     * @return The converted JSON
+     */
+    private JsonObject toJson(PasswordChangedResult result) {
+        JsonObject json = new JsonObject();
+        json.addProperty("auth", result.getAuth());
+        json.addProperty("recovery", B(result.hasRecovery()));
+        return json;
+    }
+
     /**
      * For a guest users first access, change temporary password saved in recovery
      */
@@ -76,7 +91,7 @@ public class GuestFirstPasswordAction extends GuardServletAction {
             question = json.get("question").getAsString();
             answer = json.get("answer").getAsString();
             email = new EmailValidator().assertInput(json.get("email").getAsString(), "email");
-            itemId = new UUIDValidator("pgp-").assertInput(json.get("itemId").getAsString(),"itemId");
+            itemId = new UUIDValidator("pgp-").assertInput(json.get("itemId").getAsString(), "itemId");
         } catch (NullPointerException e) {
             throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("JSON requires newpass, question, answer, email, itemid");
         }
@@ -103,7 +118,7 @@ public class GuestFirstPasswordAction extends GuardServletAction {
 
         // Here, let's verify the itemId exists
         Storage storage = Services.getService(Storage.class);
-        try(InputStream in = storage.readObj(itemId);){
+        try (InputStream in = storage.readObj(itemId);) {
             if (in == null) {
                 antiabuse.addBad(ip);
                 throw GuestServletExceptionCodes.BAD_EMAIL_ID.create();
@@ -113,11 +128,7 @@ public class GuestFirstPasswordAction extends GuardServletAction {
         // OK, verified.  Let's change the password
         PasswordChangeService passService = Services.getService(PasswordChangeService.class);
         OxCookie cookie = new OxCookie(request.getCookies());
-        String retJson = passService.changePassword(keys.getUserid(), keys.getContextid(), email, "", newpass, question, answer, pin, cookie.getOxReaderID());
-        ServletUtils.sendOK(response, "application/json", retJson);
-
-
-
+        PasswordChangedResult result = passService.changePassword(keys.getUserid(), keys.getContextid(), email, "", newpass, question, answer, pin, cookie.getOxReaderID());
+        ServletUtils.sendJson(response, toJson(result));
     }
-
-}
+}
\ No newline at end of file
