@@ -26,10 +26,10 @@ import javax.servlet.http.HttpServletResponse;
 import org.json.JSONObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.guest.GuestConverterService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.guest.exceptions.GuestServletExceptionCodes;
 import com.openexchange.guard.user.UserIdentity;
 
