@@ -26,7 +26,6 @@ import java.util.HashMap;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.AbstractGuardServlet;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.OXGuardSessionAuthenticationHandler;
@@ -53,6 +52,7 @@ import com.openexchange.guard.servlets.keymanagement.actions.TransferAutoCryptKe
 import com.openexchange.guard.servlets.keymanagement.actions.UploadExternalPublicKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.UploadKeysAction;
 import com.openexchange.guard.servlets.keymanagement.actions.VerifyAutoCryptKeyAction;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link KeymanagementServlet}
