@@ -27,6 +27,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.inputvalidation.EmailValidator;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
@@ -38,7 +39,6 @@ import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.keymanagement.responses.GuardKeyInfoResponse;
 import com.openexchange.guard.user.UserIdentity;
 
