@@ -28,7 +28,7 @@ package com.openexchange.guard.servlets.keymanagement.actions;
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v2.6.0
  */
-class Parameters {
+public class Parameters {
     public static final String PARAM_KEYID = "keyid";
     public static final String PARAM_KEYIDS = "keyids";
     public static final String PARAM_NAME = "name";
