@@ -23,16 +23,14 @@ package com.openexchange.guard.servlets.keymanagement.actions;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.autocrypt.AutoCryptService;
-import com.openexchange.guard.common.servlets.responses.CommonResponse;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 
 /**
  * {@link PutAutoCryptKey}
@@ -43,14 +41,10 @@ import com.openexchange.guard.servlets.authentication.GuardUserSession;
 public class PutAutoCryptKey extends GuardServletAction {
 
     private static final String HEADER_PARAM = "header";
-    private static final String FROM_ADDR = "from";
     private static final String ADD_IF_NEW = "add";
     private static final String CONFIRMED = "confirmed";
     private static final String SENT_DATE = "date";
 
-    /* (non-Javadoc)
-     * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
-     */
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
         JsonObject json = Services.getService(ResponseHandler.class).getJson(request);
@@ -58,7 +52,7 @@ public class PutAutoCryptKey extends GuardServletAction {
             throw OXException.mandatoryField("Missing header data");
         }
         String header = json.get(HEADER_PARAM).getAsString();
-        Long sentDate = json.get(SENT_DATE).getAsLong();
+        long sentDate = json.get(SENT_DATE).getAsLong();
         boolean add = ServletUtils.getBooleanParameter(request, ADD_IF_NEW);
         boolean confirmed = ServletUtils.getBooleanParameter(request, CONFIRMED);
         AutoCryptService autoCryptService = Services.getService(AutoCryptService.class);
