@@ -21,11 +21,13 @@
 
 package com.openexchange.guard.servlets.keymanagement.actions;
 
+import static com.openexchange.java.Autoboxing.l;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseAction;
@@ -34,7 +36,6 @@ import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.RevocationReason;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.user.UserIdentity;
 
 /**
@@ -45,19 +46,14 @@ import com.openexchange.guard.user.UserIdentity;
  */
 public class RevokeKeyAction extends GuardServletAction {
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
-     */
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
         final boolean mandatory = true;
-        final long keyId = ServletUtils.getLongParameter(request, Parameters.PARAM_KEYID, mandatory);
+        final Long keyId = ServletUtils.getLongParameter(request, Parameters.PARAM_KEYID, mandatory);
         final UserIdentity userIdentity = requireUserIdentityFrom(request, userSession.getUserId(), userSession.getContextId());
         final String reason = ServletUtils.getStringParameter(request, Parameters.PARAM_REASON);
         final GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        final GuardKeys key = keyService.getKeysBySubKeyId(userSession.getGuardUserId(), userSession.getGuardContextId(), keyId);
+        final GuardKeys key = keyService.getKeysBySubKeyId(userSession.getGuardUserId(), userSession.getGuardContextId(), l(keyId));
         if (key != null) {
 
             //Revoke the key in a brute force protected way
@@ -80,6 +76,7 @@ public class RevokeKeyAction extends GuardServletAction {
                     return null;
                 }
             });
+            ServletUtils.sendJsonOK(response);
         } else {
             throw GuardCoreExceptionCodes.KEY_NOT_FOUND.create();
         }
