@@ -21,15 +21,13 @@
 
 package com.openexchange.guard.servlets.keymanagement.actions;
 
+import java.util.Map;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
-import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
-import com.openexchange.guard.keymanagement.commons.GuardKeys;
-import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
+import com.openexchange.guard.servlets.keymanagement.pgp.SetCurrentPGPKey;
 
 /**
  * {@link SetCurrentKeyAction} marks a Guard Key Ring as "current".
@@ -39,20 +37,15 @@ import com.openexchange.guard.servlets.authentication.GuardUserSession;
  */
 public class SetCurrentKeyAction extends GuardServletAction {
 
-    /* (non-Javadoc)
-     * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
-     */
+
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
-        final long keyId = ServletUtils.getLongParameter(request, Parameters.PARAM_KEYID, true);
-        GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        GuardKeys keys = keyService.getKeys(userSession.getGuardUserId(), userSession.getGuardContextId(), keyId);
-        if(keys != null) {
-            keyService.setCurrentKey(keys);
-            ServletUtils.sendJsonOK(response, null);
-        }
-        else {
-            throw GuardCoreExceptionCodes.KEY_NOT_FOUND.create();
+        Map<String, String[]> params = getHttpParameters(request);
+        final Long keyId = ServletUtils.getLongParameter(params, Parameters.PARAM_KEYID, true);
+        if (SetCurrentPGPKey.setCurrentPGP(keyId, userSession.getUserId(), userSession.getContextId())) {
+            ServletUtils.sendJsonOK(response);
+            return;
         }
+        ServletUtils.sendError(response, "Error updating keys");
     }
 }
