@@ -24,10 +24,10 @@ package com.openexchange.guard.servlets.keymanagement.actions;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.keymanagement.services.PublicExternalKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 
 /**
  * {@link SetExternalKeyInlineModeAction}
@@ -49,5 +49,6 @@ public class SetExternalKeyInlineModeAction extends GuardServletAction {
         }
         boolean inline = ServletUtils.getBooleanParameter(request, Parameters.PARAM_INLINE, true);
         externalKeyService.setInline(userSession.getUserId(), userSession.getContextId(), ids, inline);
+        ServletUtils.sendJsonOK(response, null);
     }
 }
