@@ -24,10 +24,10 @@ package com.openexchange.guard.servlets.keymanagement.actions;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.keymanagement.services.PublicExternalKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 
 /**
  * {@link SetExternalKeyShareModeAction} sets the share mode of an uploaded public key for an external recipient
@@ -49,5 +49,6 @@ public class SetExternalKeyShareModeAction extends GuardServletAction {
         }
         boolean share = ServletUtils.getBooleanParameter(request, Parameters.PARAM_SHARE, true);
         externalKeyService.share(userSession.getUserId(), userSession.getContextId(), ids, share);
+        ServletUtils.sendJsonOK(response, null);
     }
 }
