@@ -24,20 +24,15 @@ package com.openexchange.guard.servlets.keymanagement.actions;
 import java.nio.charset.StandardCharsets;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import com.google.gson.JsonArray;
-import com.google.gson.JsonObject;
-import com.openexchange.exception.OXException;
 import com.openexchange.guard.autocrypt.AutoCryptService;
-import com.openexchange.guard.common.servlets.responses.CommonResponse;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
-import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.ApiResponse;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 
 /**
  * {@link StartAutoCryptKeyImport}
@@ -52,9 +47,6 @@ public class StartAutoCryptKeyImport extends GuardServletAction {
     private static final String ATTACHMENT_PARAMT = "attachment";
 
 
-    /* (non-Javadoc)
-     * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
-     */
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
         Api api = new Api(new OxCookie(request.getCookies()), request);
