@@ -25,10 +25,10 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.autocrypt.database.AutoCryptStorageService;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 /**
  * {@link VerifyAutoCryptKeyAction}
  *
@@ -37,9 +37,6 @@ import com.openexchange.guard.servlets.authentication.GuardUserSession;
  */
 public class VerifyAutoCryptKeyAction extends GuardServletAction {
 
-    /* (non-Javadoc)
-     * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
-     */
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
         boolean verified = ServletUtils.getBooleanParameter(request, Parameters.PARAM_VERIFIED, true);
