@@ -24,11 +24,11 @@ package com.openexchange.guard.servlets.login;
 import java.util.HashMap;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import com.openexchange.exception.OXException;
 import com.openexchange.guard.servlets.AbstractGuardServlet;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardAuthenticationHandler;
 import com.openexchange.guard.servlets.authentication.OXGuardSessionAuthenticationHandler;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * Provides login and authentication functionality for OX Guard
@@ -45,16 +45,17 @@ public class LoginServlet extends AbstractGuardServlet {
     private static final String LOGIN_ACTION = "login";
     private static final String LOGIN_GUEST_ACTION = "guest";
     private static final String CHANGE_PASSWORD_ACTION = "changepass";
-    private static final String CREATE_KEYS_ACTION = "create";
     private static final String CHANGE_SECONDARY_EMAIL_ACTION = "changesecondary";
     private static final String DELETE_RECOVERY_ACTION = "deleterecovery";
     private static final String DELETE_SESSION = "delete_session";
+    @Deprecated
+    private static final String CREATE_KEYS_ACTION = "create";
 
     private transient final HashMap<String, GuardServletAction> servletGetActions;
     private transient final HashMap<String, GuardServletAction> servletPostActions;
     private transient final HashMap<String, GuardServletAction> servletPutActions;
 
-    public LoginServlet(GuardAuthenticationHandler basicAuthServletAuthentication ) throws OXException {
+    public LoginServlet(ServiceLookup services, GuardAuthenticationHandler basicAuthServletAuthentication) {
 
         OXGuardSessionAuthenticationHandler uiSessionAuthentication = new OXGuardSessionAuthenticationHandler();
 
@@ -66,12 +67,12 @@ public class LoginServlet extends AbstractGuardServlet {
 
         //POST
         servletPostActions = new HashMap<String, GuardServletAction>();
-        servletPostActions.put(LOGIN_ACTION, new LoginAction().setAuthenticationHandler(uiSessionAuthentication));
+        servletPostActions.put(LOGIN_ACTION, new LoginAction(services).setAuthenticationHandler(uiSessionAuthentication));
         servletPostActions.put(LOGIN_GUEST_ACTION, new LoginGuestAction());
         servletPostActions.put(CHANGE_PASSWORD_ACTION, new ChangePasswordAction().setAuthenticationHandler(uiSessionAuthentication));
         servletPostActions.put(CREATE_KEYS_ACTION, new CreateKeysActions().setAuthenticationHandler(uiSessionAuthentication));
         servletPostActions.put(CHANGE_SECONDARY_EMAIL_ACTION, new ChangeSecondaryEmailAction().setAuthenticationHandler(uiSessionAuthentication));
-        servletPostActions.put(DELETE_RECOVERY_ACTION, new DeleteRecoveryAction().setAuthenticationHandler(uiSessionAuthentication));
+        servletPostActions.put(DELETE_RECOVERY_ACTION, new DeleteRecoveryAction(services).setAuthenticationHandler(uiSessionAuthentication));
 
         //PUT
         servletPutActions = new HashMap<String, GuardServletAction>();
