@@ -25,10 +25,8 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.auth.LogoutHandler;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
-import com.openexchange.guard.oxapi.OxCookie;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
-
 
 /**
  * Logout for OX Guard
