@@ -32,10 +32,10 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
 import com.openexchange.guard.sharing.SharingService;
@@ -55,9 +55,6 @@ public class ChangeShareAction extends GuardServletAction {
     private static final String UPDATED_SHARES_JSON_ARRAY = "updatedShares";
     private static final String USER_ID = "id";
 
-    /* (non-Javadoc)
-     * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
-     */
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
         SharingService sharing = Services.getService(SharingService.class);
