@@ -27,10 +27,10 @@ import org.apache.http.HttpStatus;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 
 /**
  * {@link CreateAuthenticationTokenAction}
@@ -43,17 +43,14 @@ public class CreateAuthenticationTokenAction extends GuardServletAction {
     private static final String SESSION_IDENTIFIER_PARAMETER_NAME = "session";
     private static final String USER_IDENTITY_PARAMETER_NAME = "identity";
     private static final String PASSWORD_PARAMETER_NAME = "password";
+    private static final String TYPE = "type";
 
     private JSONObject createResponseJson(String authToken) throws JSONException {
         JSONObject ret = new JSONObject();
         ret.put("auth", authToken);
         return ret;
     }
-    /*
-     * (non-Javadoc)
-     * 
-     * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
-     */
+
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
 
@@ -62,8 +59,12 @@ public class CreateAuthenticationTokenAction extends GuardServletAction {
         String sessionIdentifier = ServletUtils.getStringParameter(request, SESSION_IDENTIFIER_PARAMETER_NAME, true);
         String userIdentity = ServletUtils.getStringParameter(request, USER_IDENTITY_PARAMETER_NAME, true);
         String password = ServletUtils.getStringParameter(request, PASSWORD_PARAMETER_NAME, true);
+        String type = ServletUtils.getStringParameter(request, TYPE, false);
+        if (type == null) {
+            type = "pgp";  // fallback
+        }
 
-        String authToken = tokenAuthService.createAuthenticationToken(sessionIdentifier, userIdentity, password.toCharArray());
+        String authToken = tokenAuthService.createAuthenticationToken(sessionIdentifier, userIdentity, password.toCharArray(), type);
         if (authToken != null) {
             ServletUtils.sendOK(response, "application/json", createResponseJson(authToken).toString());
         }
