@@ -27,12 +27,12 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.fileupload.FileItem;
 import org.json.JSONObject;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
 import com.openexchange.guard.user.UserIdentity;
