@@ -28,13 +28,13 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.fileupload.FileItem;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
-import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.core.SignatureVerificationResult;
 
 /**
  * {@link VerifyAction}
@@ -64,7 +64,7 @@ public class VerifyAction extends GuardServletAction {
 
             PGPSigningService signingService = Services.getService(PGPSigningService.class);
             response.setContentType(CONTENT_TYPE_JSON);
-            List<PGPSignatureVerificationResult> verifyResults = signingService.verify(dataStream, signatureStream);
+            List<SignatureVerificationResult> verifyResults = signingService.verify(dataStream, signatureStream);
             ServletUtils.sendJsonOK(response, VerifyResultJsonFactory.toJson(verifyResults));
         }
     }
