@@ -25,7 +25,9 @@ import java.util.List;
 import com.google.gson.JsonArray;
 import com.google.gson.JsonElement;
 import com.google.gson.JsonObject;
+import com.openexchange.exception.OXException;
 import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.core.SignatureVerificationResult;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 
@@ -46,11 +48,15 @@ public class VerifyResultJsonFactory {
     private static final String ISSUER_KEY_FINGERPRINT_PROPERTY = "issuerKeyFingerprint";
     private static final String ISSUER_KEY_ID_PROPERTY = "issuerKeyId";
 
-    public static JsonElement toJson(List<PGPSignatureVerificationResult> results) {
+    public static JsonElement toJson(List<SignatureVerificationResult> results) throws OXException {
         JsonObject json = new JsonObject();
         JsonArray array = new JsonArray();
-        for(PGPSignatureVerificationResult result : results) {
-            array.add(toJson(result));
+        for (SignatureVerificationResult result : results) {
+            if (result instanceof PGPSignatureVerificationResult) {
+                array.add(toJson((PGPSignatureVerificationResult) result));
+            } else {
+                throw OXException.general("Unexpected signature result type");
+            }
         }
         json.add(RESULTS_PROPERTY, array);
         return json;
