@@ -31,10 +31,13 @@ import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.fileupload.FileUploadException;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.crypto.CryptoType;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.crypto.CryptoManager;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.inputvalidation.RangeInputValidator;
 import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseAction;
@@ -43,17 +46,19 @@ import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.mime.services.MimeEncryptionService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
+import com.openexchange.guard.servlets.crypto.Exceptions.CryptoServletExceptionCodes;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
 import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link DecryptMimeEmailAction}
- *
+ * 
+ * @deprecated as of 2.10.7. Use {@link com.openexchange.guard.servlets.crypto.DecryptMimeEmailAction}
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v7.8.4
  */
+@Deprecated
 public class DecryptMimeEmailAction extends GuardServletAction {
 
     private static final String JSON_DATA_FIELD_NAME = "json";
@@ -99,12 +104,22 @@ public class DecryptMimeEmailAction extends GuardServletAction {
                 @Override
                 public Void doAction() throws Exception {
                     final GuardParsedMimeMessage parsedMimeMessage = parseMimeMessage(request, json, messageStream, userId, contextId);
-                    MimeEncryptionService mimeEncryptor = Services.getService(MimeEncryptionService.class);
-                    mimeEncryptor.doDecryption(parsedMimeMessage, userId, contextId, closureUserIdentity, response.getOutputStream());
+                    doDecryption(request, response, parsedMimeMessage, userId, contextId, closureUserIdentity);
                     return null;
                 }
             });
         }
     }
 
+    private static void doDecryption(HttpServletRequest request, HttpServletResponse response, GuardParsedMimeMessage parsedMimeMessage, int userId, int contextId, UserIdentity userIdentity)
+        throws OXException, IOException {
+        // Check handled
+        CryptoManager cryptoManager = Services.getService(CryptoManager.class);
+        MimeEncryptionService mimeEncryptor = cryptoManager.getMimeEncryptionService(CryptoType.PROTOCOL.PGP);
+        if (mimeEncryptor != null) {
+            mimeEncryptor.doDecryption(parsedMimeMessage, userId, contextId, userIdentity, response.getOutputStream());
+        } else {
+            throw CryptoServletExceptionCodes.UNKNOWN_CRYPTO_TYPE.create();
+        }
+    }
 }
