@@ -31,13 +31,13 @@ import org.apache.commons.fileupload.FileItem;
 import org.slf4j.Logger;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.inputvalidation.RangeInputValidator;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.mime.services.MimeParser;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.pgp.mail.PGPMimeService;
 import com.openexchange.server.ServiceLookup;
@@ -45,9 +45,11 @@ import com.openexchange.server.ServiceLookup;
 /**
  * {@link EncryptAction} Action to encrypt an incoming email
  *
+ * @deprecated As of 2.10.7. Use {@link com.openexchange.guard.servlets.crypto.MimeEmailAction}
  * @author <a href="mailto:greg.hill@open-xchange.com">Greg Hill</a>
  * @since v2.10.4
  */
+@Deprecated
 public class EncryptAction extends GuardServletAction {
 
     private static final Logger Log = org.slf4j.LoggerFactory.getLogger(EncryptAction.class);
