@@ -36,9 +36,12 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.io.IOUtils;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
+import com.openexchange.crypto.CryptoType;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
+import com.openexchange.guard.crypto.CryptoManager;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.OGPGPKeyRing;
 import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseAction;
@@ -52,7 +55,6 @@ import com.openexchange.guard.oxapi.ApiResponse;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.keymanagement.responses.ExternalPublicKeyRingCollectionResponse;
 import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.pgp.keys.parsing.PGPPublicKeyRingFactory;
@@ -110,7 +112,7 @@ public class GetPublicKeyFromAttachmentAction extends GuardServletAction {
         MimeMessage mimeMessage = new MimeMessage(
             Session.getDefaultInstance(new Properties()),
             new ByteArrayInputStream(oxapi.getMime(emailid, folder).getBytes(StandardCharsets.UTF_8)));
-        MimeEncryptionService mimeCryptoService = Services.getService(MimeEncryptionService.class);
+        MimeEncryptionService mimeCryptoService = Services.getService(CryptoManager.class).getMimeEncryptionService(CryptoType.PROTOCOL.PGP);
         Part decryptedPart = mimeCryptoService.doDecryption(mimeMessage, filename, userIdentity);
         return decryptedPart == null ? null : createKeyRing(decryptedPart.getInputStream());
     }
