@@ -31,28 +31,35 @@ import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.fileupload.FileUploadException;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.crypto.CryptoType;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.crypto.CryptoManager;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.inputvalidation.RangeInputValidator;
 import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.mime.services.MimeEncryptionService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
+import com.openexchange.guard.servlets.crypto.Exceptions.CryptoServletExceptionCodes;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
 import com.openexchange.guard.user.UserIdentity;
 
 /**
- * Encrypt an email
- *
+ * {@link MimeEmailAction} - Encrypt an email
+ * 
+ * @deprecated As of 2.10.7. Use {@link com.openexchange.guard.servlets.crypto.MimeEmailAction}
  * @author <a href="mailto:greg.hill@open-xchange.com">Greg Hill</a>
  * @since v2.4.0
  */
+@Deprecated
 public class MimeEmailAction extends GuardServletAction {
 
+    ///////////////////  DEPRECATED FOR CRYPTO SERVICE ////////////////////////////////////
+
 	private static final String JSON_DATA_FIELD_NAME = "json";
 	private static final String JSON_AUTH_FIELD_NAME = "guardAuth";
 	private static final String MESSAGE_FIELD_NAME = "file";
@@ -91,8 +98,13 @@ public class MimeEmailAction extends GuardServletAction {
             String password = signingIdentity != null ? new String(signingIdentity.getPassword()) : null;
 
             final GuardParsedMimeMessage parsedMimeMessage = parseMimeMessage(request, json, messageStream, userId, contextId, fromName, senderEmail, senderIsGuest);
-            MimeEncryptionService mimeEncryptor = Services.getService(MimeEncryptionService.class);
-            mimeEncryptor.doEncryption(parsedMimeMessage, userId, contextId, password, response.getOutputStream());
+            CryptoManager cryptoManager = Services.getService(CryptoManager.class);
+            MimeEncryptionService mimeEncryptor = cryptoManager.getMimeEncryptionService(CryptoType.PROTOCOL.PGP);
+            if (mimeEncryptor != null) {
+                mimeEncryptor.doEncryption(parsedMimeMessage, userId, contextId, password, response.getOutputStream());
+            } else {
+                throw CryptoServletExceptionCodes.UNKNOWN_CRYPTO_TYPE.create();
+            }
         }
     }
 }
