@@ -21,6 +21,9 @@
 
 package com.openexchange.guard.servlets.pgpmail;
 
+import static com.openexchange.java.Autoboxing.B;
+import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.i;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.Collection;
@@ -30,36 +33,42 @@ import javax.mail.internet.MimeMessage;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.fileupload.FileItem;
-import org.apache.commons.fileupload.FileUploadException;
 import org.json.JSONException;
+import com.openexchange.crypto.CryptoType;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.auth.AuthUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.common.util.GuardMimeHeaders;
 import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.crypto.CryptoManager;
+import com.openexchange.guard.crypto.MimeSignatureVerificationService;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.inputvalidation.RangeInputValidator;
 import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.osgi.Services;
-import com.openexchange.guard.pgpcore.services.PGPMimeSigningService;
-import com.openexchange.guard.pgpcore.services.PGPSignatureVerificationResultUtil;
+import com.openexchange.guard.pgpcore.services.SignatureVerificationResultUtil;
 import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExceptionCodes;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.user.UserIdentity;
-import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.core.SignatureVerificationResult;
 
 /**
  * {@link VerifyMimeEmailAction}
- *
+ * 
+ * @deprecated as of 2.10.7. Use {@link com.openexchange.guard.servlets.crypto.VerifyMimeEmailAction}
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v7.8.4
  */
+@Deprecated
 public class VerifyMimeEmailAction extends GuardServletAction {
 
+    ////////////////////////  DEPRECATED FOR CRYPTO SERVICE /////////////////////////
+
     private static final String MESSAGE_FIELD_NAME = "file";
 
-    private static GuardParsedMimeMessage parseMimeMessage(HttpServletRequest request, InputStream message, int userId, int contextId) throws MessagingException, JSONException, OXException, FileUploadException, IOException {
+    private static GuardParsedMimeMessage parseMimeMessage(HttpServletRequest request, InputStream message, int userId, int contextId) throws MessagingException, JSONException, OXException, IOException {
         return ParseIncoming.parse(request, null, message, userId, contextId, null, null, false);
     }
 
@@ -71,30 +80,25 @@ public class VerifyMimeEmailAction extends GuardServletAction {
      * @param response
      * @param verificationResults
      */
-    private static void sendSimpleResponse(HttpServletResponse response, List<PGPSignatureVerificationResult> verificationResults) {
+    private static void sendSimpleResponse(HttpServletResponse response, List<SignatureVerificationResult> verificationResults) {
         if (verificationResults == null) {
             ServletUtils.sendObject(response, "missing");
             return;
         }
         boolean verified = false;
-        for (PGPSignatureVerificationResult result : verificationResults) {
+        for (SignatureVerificationResult result : verificationResults) {
             verified = verified || result.isVerified();
         }
-        ServletUtils.sendObject(response, verified);
+        ServletUtils.sendObject(response, B(verified));
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
-     */
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
-        RangeInputValidator<Integer> positiveValidator = new RangeInputValidator<Integer>(0, Integer.MAX_VALUE);
+        RangeInputValidator<Integer> positiveValidator = new RangeInputValidator<Integer>(I(0), I(Integer.MAX_VALUE));
 
         final boolean mandatory = true;
-        final int userId = positiveValidator.assertInput(ServletUtils.getIntParameter(request, "user", mandatory), "user");
-        final int contextId = positiveValidator.assertInput(ServletUtils.getIntParameter(request, "context", mandatory), "context");
+        final int userId = i(positiveValidator.assertInput(ServletUtils.getIntParameter(request, "user", mandatory), "user"));
+        final int contextId = i(positiveValidator.assertInput(ServletUtils.getIntParameter(request, "context", mandatory), "context"));
         final boolean simpleResponse = ServletUtils.getBooleanParameter(request, "simple");
 
         FileUploadHandler fileUploadHandler = new FileUploadHandler(Services.getService(GuardConfigurationService.class));
@@ -105,16 +109,20 @@ public class VerifyMimeEmailAction extends GuardServletAction {
 
             final MimeMessage messageToVerify = parsedMimeMessage.getMessage();
 
-            //new:
+            CryptoManager manager = Services.getService(CryptoManager.class);
+            MimeSignatureVerificationService mimeSigningService = manager.getSignatureVerificationService(CryptoType.PROTOCOL.PGP);
+            if (mimeSigningService == null) {
+                // No service response
+                throw GuardCoreExceptionCodes.UNKOWN_SIGNATURE_TYPE.create();
+            }
             messageToVerify.removeHeader(GuardMimeHeaders.X_GUARD_SIGNATURE_RESULT);
-            PGPMimeSigningService pgpMimeSigningService = Services.getService(PGPMimeSigningService.class);
-            List<PGPSignatureVerificationResult> verificationResults = pgpMimeSigningService.verify(messageToVerify, userIdentity);
+            List<SignatureVerificationResult> verificationResults = mimeSigningService.verify(messageToVerify, userIdentity);
             if (simpleResponse) {
                 sendSimpleResponse(response, verificationResults);
                 return;
             }
             if (verificationResults != null) {
-                String[] headers = PGPSignatureVerificationResultUtil.toHeaders(verificationResults);
+                String[] headers = SignatureVerificationResultUtil.toHeaders(verificationResults);
                 for (String header : headers) {
                     messageToVerify.addHeader(GuardMimeHeaders.X_GUARD_SIGNATURE_RESULT, header);
                 }
