@@ -24,12 +24,12 @@ package com.openexchange.guard.servlets.supportApi;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.session.GuardUserSession;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.inputvalidation.EmailValidator;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
-import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.support.PasswordReseter.EmailTarget;
 import com.openexchange.guard.support.SupportService;
 import com.openexchange.guard.support.SupportServiceImpl;
@@ -58,8 +58,7 @@ public class ResetPasswordAction extends GuardServletAction {
         String language = ServletUtils.getStringParameter(request, "language", false /* optional */);
         if (language == null || language.isEmpty()) {
             GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-            language = configService.getProperty(GuardProperty.defaultLanguage,
-                userSession.getUserId(), userSession.getContextId());
+            language = configService.getProperty(GuardProperty.defaultLanguage, userSession.getUserId(), userSession.getContextId());
         }
 
         //Resetting the user's password
