@@ -31,7 +31,7 @@ public class SupportServlet extends AbstractGuardServlet {
     private static final String RESET_PASSWORD_ACTION = "reset_password";
     private static final String DELETE_USER_ACTION = "delete_user";
     private static final String UPGRADE_GUEST = "upgrade_guest";
-    private final HashMap<String, GuardServletAction> postActions;
+    private transient final HashMap<String, GuardServletAction> postActions;
 
 
     /**
