@@ -18,6 +18,7 @@ import com.openexchange.guard.keymanagement.storage.DeletedKeysStorage;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.smime.SmimeKeyService;
 import com.openexchange.guard.storage.Storage;
 import com.openexchange.guard.storage.cache.FileCacheItem;
 import com.openexchange.guard.storage.cache.FileCacheStorage;
@@ -32,6 +33,14 @@ public class UserDeleter {
 
     private static final Logger LOG = LoggerFactory.getLogger(UserDeleter.class);
 
+    private <S extends Object> S getOptService(final Class<? extends S> clazz) throws OXException {
+        final S service = Services.getService(clazz);
+        if (service == null) {
+            LOG.warn("Unable to get service {} .  User data from that service will not be removed.", clazz.getSimpleName());
+        }
+        return service;
+    }
+
     private void backupKeys(List<GuardKeys> keys) throws OXException {
         //Backup keys to deleted key table / backup table
         ArrayList<DeletedKey> deletedKeys = new ArrayList<DeletedKey>();
@@ -80,6 +89,20 @@ public class UserDeleter {
         autocryptStorage.deleteAllForUser(userId, contextId);
     }
 
+    private void deleteSmime(int userId, int contextId) throws OXException {
+        if (contextId < 0) {
+            return;
+        }
+        getOptService(SmimeKeyService.class).deleteKeys(userId, contextId);
+    }
+
+    private void deleteSmime(int contextId) throws OXException {
+        if (contextId < 0) {
+            return;
+        }
+        getOptService(SmimeKeyService.class).deleteKeys(contextId);
+    }
+
     private void deleteGuestData(int userId, int contextId) throws OXException {
         // Cleanup metadata
         GuardGuestEMailMetadataService guestMetaService = Services.getService(GuardGuestEMailMetadataService.class);
@@ -151,6 +174,7 @@ public class UserDeleter {
         removeKeys(contextId);
         //The order matters: removing the email mapping at the end, because it contains the shard id for the other operations
         removeEmailMappings(contextId);
+        deleteSmime(contextId);
     }
 
     /**
@@ -212,6 +236,7 @@ public class UserDeleter {
         }
         // Cleanup UI configuration if able
         tryDeleteConfig(userId, contextId);
+        deleteSmime(userId, contextId);
 
     }
 }
